<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查必要的表是否存在，不存在则创建
try {
    // 检查inventory_checks表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'inventory_checks'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $pdo->exec("
            -- 创建库存盘点表
            CREATE TABLE IF NOT EXISTS `inventory_checks` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '盘点ID',
              `batch_number` VARCHAR(50) NOT NULL COMMENT '盘点批次号',
              `check_date` DATE NOT NULL COMMENT '盘点日期',
              `storage_location_id` INT UNSIGNED NOT NULL COMMENT '仓库位置ID',
              `notes` TEXT DEFAULT NULL COMMENT '盘点备注',
              `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '盘点人员ID',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              UNIQUE KEY `uk_inventory_check_batch_number` (`batch_number`),
              KEY `idx_inventory_check_location` (`storage_location_id`),
              KEY `idx_inventory_check_user` (`created_by_user_id`),
              KEY `idx_inventory_check_date` (`check_date`),
              CONSTRAINT `fk_inventory_check_location` FOREIGN KEY (`storage_location_id`) REFERENCES `storage_locations` (`id`) ON DELETE RESTRICT,
              CONSTRAINT `fk_inventory_check_user` FOREIGN KEY (`created_by_user_id`) REFERENCES `users` (`id`) ON DELETE SET NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='库存盘点主表'
        ");
    }

    // 检查inventory_check_items表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'inventory_check_items'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $pdo->exec("
            -- 创建库存盘点明细表
            CREATE TABLE IF NOT EXISTS `inventory_check_items` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '盘点明细ID',
              `inventory_check_id` INT UNSIGNED NOT NULL COMMENT '关联盘点ID',
              `product_id` INT UNSIGNED NOT NULL COMMENT '产品ID',
              `system_quantity` DECIMAL(10, 2) NOT NULL COMMENT '系统库存数量',
              `actual_quantity` DECIMAL(10, 2) NOT NULL COMMENT '实际盘点数量',
              `difference` DECIMAL(10, 2) GENERATED ALWAYS AS (`actual_quantity` - `system_quantity`) STORED COMMENT '差异数量',
              `notes` TEXT DEFAULT NULL COMMENT '明细备注',
              PRIMARY KEY (`id`),
              KEY `idx_inventory_check_item_check` (`inventory_check_id`),
              KEY `idx_inventory_check_item_product` (`product_id`),
              KEY `idx_inventory_check_item_difference` (`difference`),
              CONSTRAINT `fk_inventory_check_item_check` FOREIGN KEY (`inventory_check_id`) REFERENCES `inventory_checks` (`id`) ON DELETE CASCADE,
              CONSTRAINT `fk_inventory_check_item_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='库存盘点明细表'
        ");
    }
} catch (PDOException $e) {
    $error = "检查或创建数据表失败：" . $e->getMessage();
}

// 获取搜索参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$location_id = isset($_GET['location_id']) ? (int)$_GET['location_id'] : 0;
$product_type = isset($_GET['product_type']) ? $_GET['product_type'] : '';
$check_date = isset($_GET['check_date']) ? $_GET['check_date'] : date('Y-m-d');

// 获取所有仓库位置
try {
    $stmt = $pdo->query("
        SELECT id, name, type, temperature_controlled, humidity_controlled
        FROM storage_locations
        ORDER BY name
    ");
    $locations = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取仓库位置失败：" . $e->getMessage();
}

// 初始化变量
$inventory = [];
$error = '';
$success = '';

// 处理表单提交 - 生成盘点表
if (isset($_POST['generate_check'])) {
    $selected_location = isset($_POST['location_id']) ? (int)$_POST['location_id'] : 0;
    $selected_type = isset($_POST['product_type']) ? $_POST['product_type'] : '';

    if ($selected_location <= 0) {
        $error = "请选择要盘点的仓库位置！";
    } else {
        try {
            $query = "
                SELECT 
                    i.id AS inventory_id,
                    p.id AS product_id,
                    p.name AS product_name,
                    p.type AS product_type,
                    p.specification,
                    i.quantity_on_hand AS system_quantity,
                    i.unit,
                    sl.name AS location_name
                FROM 
                    inventory i
                JOIN 
                    products p ON i.product_id = p.id
                JOIN 
                    storage_locations sl ON i.storage_location_id = sl.id
                WHERE 
                    i.storage_location_id = ?
            ";

            $params = [$selected_location];

            if (!empty($selected_type)) {
                $query .= " AND p.type = ?";
                $params[] = $selected_type;
            }

            $query .= " ORDER BY p.type, p.name";

            $stmt = $pdo->prepare($query);
            $stmt->execute($params);
            $inventory = $stmt->fetchAll();

            if (empty($inventory)) {
                $error = "所选仓库位置没有库存记录！";
            } else {
                $success = "已生成盘点表，请填写实际数量后提交。";
                $location_id = $selected_location;
                $product_type = $selected_type;
            }
        } catch (PDOException $e) {
            $error = "生成盘点表失败：" . $e->getMessage();
        }
    }
}

// 处理表单提交 - 提交盘点结果
if (isset($_POST['submit_check'])) {
    try {
        // 开始事务
        $pdo->beginTransaction();

        $check_date = isset($_POST['check_date']) ? $_POST['check_date'] : date('Y-m-d');
        $check_notes = isset($_POST['check_notes']) ? $_POST['check_notes'] : '';
        $inventory_ids = isset($_POST['inventory_id']) ? $_POST['inventory_id'] : [];
        $actual_quantities = isset($_POST['actual_quantity']) ? $_POST['actual_quantity'] : [];

        // 检查是否有数据提交
        if (empty($inventory_ids)) {
            throw new Exception("没有提交盘点数据！");
        }

        // 生成盘点批次号
        $batch_number = 'INV-CHECK-' . date('YmdHis');

        // 记录盘点总记录
        $stmt = $pdo->prepare("
            INSERT INTO inventory_checks (
                batch_number, 
                check_date, 
                storage_location_id, 
                notes, 
                created_by_user_id
            ) VALUES (?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $batch_number,
            $check_date,
            $_POST['location_id'],
            $check_notes,
            $_SESSION['user_id']
        ]);

        $check_id = $pdo->lastInsertId();

        // 记录每个产品的盘点详情
        foreach ($inventory_ids as $idx => $inventory_id) {
            if (!isset($actual_quantities[$idx]) || $actual_quantities[$idx] === '') {
                continue; // 跳过未填写的项
            }

            $system_quantity = $_POST['system_quantity'][$idx];
            $actual_quantity = $actual_quantities[$idx];
            $difference = $actual_quantity - $system_quantity;
            $product_id = $_POST['product_id'][$idx];

            // 插入盘点详情
            $stmt = $pdo->prepare("
                INSERT INTO inventory_check_items (
                    inventory_check_id,
                    product_id,
                    system_quantity,
                    actual_quantity,
                    notes
                ) VALUES (?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $check_id,
                $product_id,
                $system_quantity,
                $actual_quantity,
                '' // 可以添加每项的备注
            ]);

            // 更新实际库存数量
            $stmt = $pdo->prepare("
                UPDATE inventory
                SET quantity_on_hand = ?,
                    last_updated = NOW()
                WHERE id = ?
            ");
            $stmt->execute([$actual_quantity, $inventory_id]);
        }

        // 提交事务
        $pdo->commit();
        $success = "盘点完成！批次号：" . $batch_number;

        // 清空盘点表，回到初始状态
        $inventory = [];
        $location_id = 0;
        $product_type = '';
    } catch (Exception $e) {
        // 回滚事务
        $pdo->rollBack();
        $error = "盘点提交失败：" . $e->getMessage();
    }
}

// 查询最近的盘点记录
try {
    $stmt = $pdo->query("
        SELECT 
            ic.id,
            ic.batch_number,
            ic.check_date,
            sl.name AS location_name,
            u.username AS created_by,
            ic.created_at,
            COUNT(ici.id) AS items_count,
            SUM(CASE WHEN ici.difference != 0 THEN 1 ELSE 0 END) AS discrepancy_count
        FROM 
            inventory_checks ic
        JOIN 
            storage_locations sl ON ic.storage_location_id = sl.id
        LEFT JOIN 
            users u ON ic.created_by_user_id = u.id
        LEFT JOIN 
            inventory_check_items ici ON ic.id = ici.inventory_check_id
        GROUP BY 
            ic.id
        ORDER BY 
            ic.check_date DESC, ic.created_at DESC
        LIMIT 10
    ");
    $recent_checks = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取盘点记录失败：" . $e->getMessage();
}

// 获取盘亏分析
$discrepancy_analysis = [];
if (isset($_GET['analyze']) && $_GET['analyze'] == 1) {
    try {
        $stmt = $pdo->query("
            SELECT 
                p.id,
                p.name,
                p.type,
                p.unit,
                COUNT(ici.id) AS check_count,
                SUM(ici.difference) AS total_difference,
                AVG(ici.difference) AS avg_difference,
                MAX(ABS(ici.difference)) AS max_difference
            FROM 
                inventory_check_items ici
            JOIN 
                products p ON ici.product_id = p.id
            WHERE 
                ici.difference != 0
            GROUP BY 
                p.id
            ORDER BY 
                ABS(SUM(ici.difference)) DESC
            LIMIT 20
        ");
        $discrepancy_analysis = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = "盘亏分析失败：" . $e->getMessage();
    }
}

// 产品类型映射
$product_type_map = [
    'raw' => '原料',
    'semi-finished' => '半成品',
    'finished' => '成品'
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>库存盘点 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式优化 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .form-group input[type="date"],
        .form-group input[type="text"],
        .form-group select,
        .form-group textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            background-color: #fff;
            box-sizing: border-box;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .form-group input:focus,
        .form-group select:focus,
        .form-group textarea:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        .form-group textarea {
            resize: vertical;
            min-height: 80px;
        }

        /* 盘点表单样式 */
        .check-form {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(220px, 1fr));
            gap: 15px;
            align-items: end;
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 6px;
            border: 1px solid #eee;
        }

        button,
        .btn-primary {
            padding: 10px 15px;
            background: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
            transition: background 0.3s;
        }

        button:hover,
        .btn-primary:hover {
            background: #2980b9;
        }

        /* 盘点表样式 */
        .table-container {
            overflow-x: auto;
            margin-top: 20px;
            background: white;
            border-radius: 6px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        table {
            width: 100%;
            border-collapse: collapse;
            font-size: 14px;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
            position: sticky;
            top: 0;
        }

        table tr:last-child td {
            border-bottom: none;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        .check-table {
            border: 1px solid #e5e5e5;
            border-radius: 6px;
            overflow: hidden;
        }

        .check-table input[type="number"] {
            width: 100px;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
            text-align: right;
        }

        .check-table input[type="number"]:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        .check-table .difference {
            font-weight: bold;
            text-align: right;
        }

        .positive {
            color: #28a745;
        }

        .negative {
            color: #dc3545;
        }

        .neutral {
            color: #6c757d;
        }

        /* 分析图表样式 */
        .analysis-container {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-top: 20px;
        }

        .analysis-card {
            flex: 1 1 300px;
            background: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            border: 1px solid #eaeaea;
        }

        .analysis-card h3 {
            margin-top: 0;
            color: #444;
            font-size: 16px;
            padding-bottom: 10px;
            border-bottom: 1px solid #f5f5f5;
            margin-bottom: 15px;
        }

        .analysis-card ul {
            margin: 0;
            padding-left: 20px;
        }

        .analysis-card li {
            margin-bottom: 8px;
            line-height: 1.5;
        }

        /* 选项卡样式 */
        .tabs {
            display: flex;
            margin-bottom: 25px;
            border-bottom: 1px solid #ddd;
            background: white;
            border-radius: 8px 8px 0 0;
            overflow: hidden;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        .tab {
            padding: 12px 20px;
            cursor: pointer;
            font-weight: bold;
            transition: all 0.3s;
            text-align: center;
            flex: 1;
            border-bottom: 3px solid transparent;
        }

        .tab:hover {
            background-color: #f8f9fa;
        }

        .tab.active {
            background: #3498db;
            color: white;
            border-bottom: 3px solid #2980b9;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
            animation: fadeIn 0.5s;
        }

        @keyframes fadeIn {
            from {
                opacity: 0;
            }

            to {
                opacity: 1;
            }
        }

        /* 消息样式 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* 搜索容器样式 */
        .search-container {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-bottom: 20px;
            padding: 20px;
            background: white;
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            border: 1px solid #eaeaea;
        }

        .search-container input,
        .search-container select,
        .search-container button {
            padding: 10px 15px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 14px;
        }

        .search-container button {
            background: #3498db;
            color: white;
            border: none;
            cursor: pointer;
            min-width: 80px;
            font-weight: bold;
        }

        .search-container button:hover {
            background: #2980b9;
        }

        /* 空状态样式 */
        .empty-state {
            text-align: center;
            padding: 40px 20px;
            background: #f8f9fa;
            border-radius: 8px;
            border: 1px dashed #ddd;
            color: #6c757d;
        }

        .empty-state p {
            margin: 0;
            font-size: 16px;
        }

        /* 警告行样式 */
        .warning-row {
            background-color: #fff3cd !important;
        }

        .warning-row:hover {
            background-color: #ffeeba !important;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>库存盘点</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <!-- 标签页导航 -->
        <div class="tabs">
            <div class="tab <?= empty($_GET['analyze']) ? 'active' : '' ?>" onclick="switchTab('check-tab')">库存盘点</div>
            <div class="tab <?= isset($_GET['analyze']) && $_GET['analyze'] == 1 ? 'active' : '' ?>" onclick="switchTab('analysis-tab')">盘亏分析</div>
        </div>

        <!-- 库存盘点标签页 -->
        <div id="check-tab" class="tab-content <?= empty($_GET['analyze']) ? 'active' : '' ?>">
            <div class="section">
                <h2>生成盘点表</h2>
                <form method="POST" action="" class="check-form">
                    <div class="form-group">
                        <label for="location_id">仓库位置:</label>
                        <select id="location_id" name="location_id" required>
                            <option value="">-- 选择仓库 --</option>
                            <?php foreach ($locations as $loc): ?>
                                <option value="<?= $loc['id'] ?>" <?= $location_id == $loc['id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($loc['name']) ?>
                                    <?= $loc['temperature_controlled'] ? ' (温控)' : '' ?>
                                    <?= $loc['humidity_controlled'] ? ' (湿控)' : '' ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="product_type">产品类型:</label>
                        <select id="product_type" name="product_type">
                            <option value="">全部类型</option>
                            <option value="raw" <?= $product_type == 'raw' ? 'selected' : '' ?>>原料</option>
                            <option value="semi-finished" <?= $product_type == 'semi-finished' ? 'selected' : '' ?>>半成品</option>
                            <option value="finished" <?= $product_type == 'finished' ? 'selected' : '' ?>>成品</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <button type="submit" name="generate_check">生成盘点表</button>
                    </div>
                </form>
            </div>

            <?php if (!empty($inventory)): ?>
                <div class="section">
                    <h2>盘点表</h2>
                    <form method="POST" action="">
                        <input type="hidden" name="location_id" value="<?= $location_id ?>">
                        <div class="form-group">
                            <label for="check_date">盘点日期:</label>
                            <input type="date" id="check_date" name="check_date" value="<?= $check_date ?>" required>
                        </div>
                        <div class="form-group">
                            <label for="check_notes">盘点备注:</label>
                            <textarea id="check_notes" name="check_notes" rows="3" placeholder="请输入盘点相关说明..."></textarea>
                        </div>

                        <div class="table-container check-table">
                            <table>
                                <thead>
                                    <tr>
                                        <th>产品名称</th>
                                        <th>产品类型</th>
                                        <th>规格</th>
                                        <th>单位</th>
                                        <th>系统库存</th>
                                        <th>实际库存</th>
                                        <th>差异</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($inventory as $index => $item): ?>
                                        <tr>
                                            <td><?= htmlspecialchars($item['product_name']) ?></td>
                                            <td><?= isset($product_type_map[$item['product_type']]) ? $product_type_map[$item['product_type']] : $item['product_type'] ?></td>
                                            <td><?= htmlspecialchars($item['specification']) ?></td>
                                            <td><?= htmlspecialchars($item['unit']) ?></td>
                                            <td>
                                                <?= number_format($item['system_quantity'], 2) ?>
                                                <input type="hidden" name="inventory_id[<?= $index ?>]" value="<?= $item['inventory_id'] ?>">
                                                <input type="hidden" name="product_id[<?= $index ?>]" value="<?= $item['product_id'] ?>">
                                                <input type="hidden" name="system_quantity[<?= $index ?>]" value="<?= $item['system_quantity'] ?>">
                                            </td>
                                            <td>
                                                <input type="number" name="actual_quantity[<?= $index ?>]" step="0.01" min="0"
                                                    placeholder="输入实际数量"
                                                    value="<?= $item['system_quantity'] ?>"
                                                    onchange="calculateDifference(this, <?= $index ?>)">
                                            </td>
                                            <td>
                                                <span id="difference_<?= $index ?>" class="difference">0.00</span>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <div style="margin-top: 20px; text-align: center;">
                            <button type="submit" name="submit_check" class="btn-primary">提交盘点结果</button>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <div class="section">
                <h2>最近盘点记录</h2>
                <div class="table-container">
                    <?php if (empty($recent_checks)): ?>
                        <div class="empty-state">
                            <p>暂无盘点记录</p>
                        </div>
                    <?php else: ?>
                        <table>
                            <thead>
                                <tr>
                                    <th>批次号</th>
                                    <th>盘点日期</th>
                                    <th>盘点仓库</th>
                                    <th>盘点人员</th>
                                    <th>盘点项目数</th>
                                    <th>差异项目数</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($recent_checks as $check): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($check['batch_number']) ?></td>
                                        <td><?= htmlspecialchars($check['check_date']) ?></td>
                                        <td><?= htmlspecialchars($check['location_name']) ?></td>
                                        <td><?= htmlspecialchars($check['created_by']) ?></td>
                                        <td><?= $check['items_count'] ?></td>
                                        <td>
                                            <?php if ($check['discrepancy_count'] > 0): ?>
                                                <span class="negative"><?= $check['discrepancy_count'] ?></span>
                                            <?php else: ?>
                                                <span class="positive">0</span>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <a href="inventory_check_details.php?id=<?= $check['id'] ?>" class="btn-link">查看详情</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- 盘亏分析标签页 -->
        <div id="analysis-tab" class="tab-content <?= isset($_GET['analyze']) && $_GET['analyze'] == 1 ? 'active' : '' ?>">
            <div class="section">
                <h2>盘亏分析</h2>
                <p>以下是所有盘点记录中差异较大的产品分析：</p>

                <div class="table-container">
                    <?php if (empty($discrepancy_analysis)): ?>
                        <div class="empty-state">
                            <p>暂无盘亏分析数据，请先进行库存盘点</p>
                        </div>
                    <?php else: ?>
                        <table>
                            <thead>
                                <tr>
                                    <th>产品名称</th>
                                    <th>产品类型</th>
                                    <th>盘点次数</th>
                                    <th>累计差异</th>
                                    <th>平均差异</th>
                                    <th>最大差异</th>
                                    <th>单位</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($discrepancy_analysis as $item): ?>
                                    <tr class="<?= $item['total_difference'] < 0 ? 'warning-row' : '' ?>">
                                        <td><?= htmlspecialchars($item['name']) ?></td>
                                        <td><?= isset($product_type_map[$item['type']]) ? $product_type_map[$item['type']] : $item['type'] ?></td>
                                        <td><?= $item['check_count'] ?></td>
                                        <td class="<?= $item['total_difference'] < 0 ? 'negative' : 'positive' ?>">
                                            <?= number_format($item['total_difference'], 2) ?>
                                        </td>
                                        <td class="<?= $item['avg_difference'] < 0 ? 'negative' : 'positive' ?>">
                                            <?= number_format($item['avg_difference'], 2) ?>
                                        </td>
                                        <td><?= number_format($item['max_difference'], 2) ?></td>
                                        <td><?= htmlspecialchars($item['unit']) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                </div>
            </div>

            <div class="section">
                <h2>盘亏原因分析</h2>
                <div class="analysis-container">
                    <div class="analysis-card">
                        <h3>常见盘亏原因</h3>
                        <ul>
                            <li>手工记录错误</li>
                            <li>产品损耗未记录</li>
                            <li>入库或出库单据遗漏</li>
                            <li>标识混淆导致计量错误</li>
                            <li>系统数据未及时更新</li>
                        </ul>
                    </div>

                    <div class="analysis-card">
                        <h3>改进建议</h3>
                        <ul>
                            <li>加强仓库管理，规范进出库流程</li>
                            <li>提高员工培训，减少操作错误</li>
                            <li>实施条码或RFID系统，提高库存准确性</li>
                            <li>定期盘点，及时发现并解决问题</li>
                            <li>完善异常处理流程</li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script>
        // 切换标签页
        function switchTab(tabId) {
            // 如果是分析标签，添加查询参数
            if (tabId === 'analysis-tab') {
                window.location.href = 'inventory_check.php?analyze=1';
            } else {
                window.location.href = 'inventory_check.php';
            }
        }

        // 计算差异
        function calculateDifference(input, index) {
            const systemQuantity = parseFloat(document.getElementsByName('system_quantity[' + index + ']')[0].value);
            const actualQuantity = parseFloat(input.value) || 0;
            const difference = actualQuantity - systemQuantity;

            const differenceElem = document.getElementById('difference_' + index);
            differenceElem.textContent = difference.toFixed(2);

            // 设置颜色
            if (difference < 0) {
                differenceElem.className = 'difference negative';
            } else if (difference > 0) {
                differenceElem.className = 'difference positive';
            } else {
                differenceElem.className = 'difference';
            }
        }
    </script>
</body>

</html>