<?php

/**
 * 配送成本分析
 * 用于分析物流配送成本数据，提供成本趋势、物流公司对比和地区对比等数据
 */

session_start();

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');
    exit;
}

// 引入配置文件
require_once '../config.php';

// 设置页面标题
$page_title = "配送成本分析";

// 默认日期范围：过去6个月
$date_to = isset($_GET['date_to']) && !empty($_GET['date_to']) ? $_GET['date_to'] : date('Y-m-d');
$date_from = isset($_GET['date_from']) && !empty($_GET['date_from']) ? $_GET['date_from'] : date('Y-m-d', strtotime('-6 months'));

// 获取筛选条件
$carrier_id = isset($_GET['carrier_id']) ? intval($_GET['carrier_id']) : 0;
$region = isset($_GET['region']) ? $_GET['region'] : '';
$order_id = isset($_GET['order_id']) ? intval($_GET['order_id']) : 0;

// 如果指定了tab参数，记录它以便在页面加载后切换到对应选项卡
$active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'overview';

// 初始化错误和成功消息
$error = "";
$success = "";

try {
    // 检查物流公司表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'carriers'");
    if (!$stmt->rowCount()) {
        // 从SQL文件中提取carriers表定义
        $sql_file = file_get_contents('../SQL/FruitEase.sql');

        // 提取carriers表的创建SQL
        if (preg_match('/CREATE TABLE\s+`carriers`\s*\((.*?)\)\s*ENGINE\s*=/s', $sql_file, $matches)) {
            // 创建carriers表（使用SQL文件中的定义）
            $create_carriers_sql = "CREATE TABLE `carriers` (" . $matches[1] . ") ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '物流承运商信息表'";
            $pdo->exec($create_carriers_sql);

            // 提取INSERT语句
            if (preg_match('/INSERT INTO\s+`carriers`(.*?);/s', $sql_file, $insert_matches)) {
                $insert_carriers_sql = "INSERT INTO `carriers`" . $insert_matches[1];
                $pdo->exec($insert_carriers_sql);
                $success = "已从SQL文件创建carriers表并插入初始数据";
            }
        } else {
            // 如果在SQL文件中找不到定义，则使用以下备用定义
            $pdo->exec("
                CREATE TABLE `carriers` (
                  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '物流公司ID',
                  `name` VARCHAR(100) NOT NULL COMMENT '公司名称',
                  `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
                  `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
                  `service_type` VARCHAR(50) DEFAULT NULL COMMENT '服务类型 (例如: 快递, 专线物流, 冷链)',
                  `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否合作',
                  PRIMARY KEY (`id`),
                  UNIQUE KEY `uk_carrier_name` (`name`)
                ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '物流承运商信息表'
            ");

            // 插入示例数据
            $pdo->exec("
                INSERT INTO
                  `carriers` (
                    `name`,
                    `contact_person`,
                    `phone`,
                    `service_type`
                  )
                VALUES
                  ('顺丰速运', '张经理', '95338', '快递, 冷链'),
                  ('德邦物流', '李主管', '95353', '专线物流, 大件运输'),
                  ('京东物流', '王先生', '950616', '快递, 仓配一体'),
                  ('本地冷链专线', '赵师傅', '13800138000', '冷链专线')
            ");
        }
    }

    // 检查shipments表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'shipments'");
    if (!$stmt->rowCount()) {
        // 从SQL文件中提取shipments表定义
        $sql_file = file_get_contents('../SQL/FruitEase.sql');

        // 提取shipments表的创建SQL
        if (preg_match('/CREATE TABLE\s+`shipments`\s*\((.*?)\)\s*ENGINE\s*=/s', $sql_file, $matches)) {
            // 创建shipments表（使用SQL文件中的定义）
            $create_shipments_sql = "CREATE TABLE `shipments` (" . $matches[1] . ") ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '发货记录表'";
            $pdo->exec($create_shipments_sql);

            // 提取INSERT语句
            if (preg_match('/INSERT INTO\s+`shipments`(.*?);\s*--/s', $sql_file, $insert_matches)) {
                $insert_shipments_sql = "INSERT INTO `shipments`" . $insert_matches[1];
                $pdo->exec($insert_shipments_sql);
                $success .= "已从SQL文件创建shipments表并插入初始数据";
            }
        } else {
            // 如果在SQL文件中找不到定义，则使用备用方式
            // 检查sales_orders表是否存在，以获取客户ID
            $stmt = $pdo->query("SHOW TABLES LIKE 'sales_orders'");

            if ($stmt->rowCount()) {
                // 创建shipments表（简化版本，与SQL文件中的字段可能不完全一致）
                $pdo->exec("
                    CREATE TABLE `shipments` (
                      `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '发货ID',
                      `shipment_number` VARCHAR(50) NOT NULL COMMENT '发货单号',
                      `sales_order_id` INT UNSIGNED NOT NULL COMMENT '关联销售订单ID',
                      `carrier_id` INT UNSIGNED DEFAULT NULL COMMENT '承运商ID',
                      `tracking_number` VARCHAR(100) DEFAULT NULL COMMENT '物流单号',
                      `shipment_date` DATETIME NOT NULL COMMENT '发货日期时间',
                      `estimated_delivery_date` DATE DEFAULT NULL COMMENT '预计送达日期',
                      `actual_delivery_date` DATETIME DEFAULT NULL COMMENT '实际送达日期时间',
                      `shipping_cost` DECIMAL(10, 2) DEFAULT NULL COMMENT '物流费用',
                      `status` ENUM(
                        'pending',
                        'ready_to_ship',
                        'shipped',
                        'in_transit',
                        'delivered',
                        'failed',
                        'cancelled'
                      ) NOT NULL DEFAULT 'pending' COMMENT '发货状态',
                      `notes` TEXT DEFAULT NULL COMMENT '备注',
                      `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                      `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                      PRIMARY KEY (`id`),
                      UNIQUE KEY `uk_shipment_number` (`shipment_number`),
                      KEY `idx_ship_order` (`sales_order_id`),
                      KEY `idx_ship_carrier` (`carrier_id`),
                      KEY `idx_ship_status` (`status`),
                      KEY `idx_ship_date` (`shipment_date`)
                    ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '发货记录表'
                ");

                // 从sales_orders表获取订单数据，用于生成示例发货单
                $orders = $pdo->query("SELECT id, order_number, customer_id, total_amount, status FROM sales_orders WHERE status = 'completed' OR status = 'processing' LIMIT 20")->fetchAll(PDO::FETCH_ASSOC);

                // 获取客户数据，提取地区信息
                $customers = [];
                $stmt = $pdo->query("SELECT id, name, region FROM customers");
                while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                    $customers[$row['id']] = $row;
                }

                // 准备物流公司数据
                $carriers = $pdo->query("SELECT id FROM carriers WHERE is_active = 1")->fetchAll(PDO::FETCH_COLUMN);

                // 插入示例发货数据
                if (!empty($orders) && !empty($carriers)) {
                    $insert_stmt = $pdo->prepare("
                        INSERT INTO shipments (
                            shipment_number, 
                            sales_order_id, 
                            carrier_id, 
                            tracking_number, 
                            shipment_date, 
                            estimated_delivery_date,
                            shipping_cost, 
                            status, 
                            notes
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
                    ");

                    foreach ($orders as $order) {
                        // 随机生成物流公司ID
                        $carrier_id = $carriers[array_rand($carriers)];

                        // 生成随机发货日期（过去6个月内）
                        $days_ago = rand(1, 180);
                        $shipment_date = date('Y-m-d H:i:s', strtotime("-$days_ago days"));
                        $estimated_delivery = date('Y-m-d', strtotime($shipment_date . ' +3 days'));

                        // 基于订单金额生成合理的运费（约订单金额的5-15%）
                        $shipping_cost = $order['total_amount'] * (rand(5, 15) / 100);

                        // 为80%的订单生成跟踪号，模拟部分订单尚未分配跟踪号
                        $tracking_number = (rand(1, 100) <= 80) ? 'SF' . rand(1000000000, 9999999999) : null;

                        // 随机状态
                        $statuses = ['pending', 'ready_to_ship', 'shipped', 'in_transit', 'delivered'];
                        $status = $statuses[array_rand($statuses)];

                        // 生成物流单号
                        $shipment_number = 'SH' . date('Ymd') . sprintf('%04d', rand(1, 9999));

                        $insert_stmt->execute([
                            $shipment_number,
                            $order['id'],
                            $carrier_id,
                            $tracking_number,
                            $shipment_date,
                            $estimated_delivery,
                            $shipping_cost,
                            $status,
                            '示例配送备注'
                        ]);
                    }

                    $success .= "创建了示例发货数据用于分析";
                }
            }
        }
    }

    // 获取所有物流公司
    $carriers = $pdo->query("SELECT id, name FROM carriers WHERE is_active = 1 ORDER BY name")->fetchAll(PDO::FETCH_ASSOC);

    // 获取所有地区
    $regions = $pdo->query("SELECT DISTINCT c.region FROM shipments s JOIN sales_orders so ON s.sales_order_id = so.id JOIN customers c ON so.customer_id = c.id WHERE c.region IS NOT NULL AND c.region != '' ORDER BY c.region")->fetchAll(PDO::FETCH_COLUMN);

    // 构建基础查询条件
    $where_conditions = ["s.shipment_date BETWEEN :date_from AND :date_to"];
    $params = [
        ':date_from' => $date_from . ' 00:00:00',
        ':date_to' => $date_to . ' 23:59:59'
    ];

    if ($carrier_id > 0) {
        $where_conditions[] = "s.carrier_id = :carrier_id";
        $params[':carrier_id'] = $carrier_id;
    }

    if (!empty($region)) {
        $where_conditions[] = "c.region = :region";
        $params[':region'] = $region;
    }

    $where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

    // 计算总订单数和总配送成本
    $query = "SELECT 
                COUNT(*) as total_shipments,
                SUM(s.shipping_cost) as total_cost,
                AVG(s.shipping_cost) as avg_cost
              FROM shipments s
              JOIN sales_orders so ON s.sales_order_id = so.id 
              JOIN customers c ON so.customer_id = c.id
              $where_clause";

    $stmt = $pdo->prepare($query);
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->execute();
    $stats = $stmt->fetch(PDO::FETCH_ASSOC);

    $total_shipments = $stats['total_shipments'] ?? 0;
    $total_cost = $stats['total_cost'] ?? 0;
    $avg_cost = $stats['avg_cost'] ?? 0;

    // 按月份统计配送成本
    $query = "SELECT 
                DATE_FORMAT(s.shipment_date, '%Y-%m') as month,
                COUNT(*) as shipment_count,
                SUM(s.shipping_cost) as total_cost,
                AVG(s.shipping_cost) as avg_cost
              FROM shipments s
              $where_clause
              GROUP BY DATE_FORMAT(s.shipment_date, '%Y-%m')
              ORDER BY month ASC";

    $stmt = $pdo->prepare($query);
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->execute();
    $monthly_costs = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 按物流公司统计配送成本
    $query = "SELECT 
                c.id,
                c.name,
                COUNT(s.id) as shipment_count,
                SUM(s.shipping_cost) as total_cost,
                AVG(s.shipping_cost) as avg_cost
              FROM shipments s
              JOIN carriers c ON s.carrier_id = c.id
              $where_clause
              GROUP BY c.id
              ORDER BY total_cost DESC";

    $stmt = $pdo->prepare($query);
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->execute();
    $cost_by_carrier = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 按地区统计配送成本
    $query = "SELECT 
                c.region,
                COUNT(*) as shipment_count,
                SUM(s.shipping_cost) as total_cost,
                AVG(s.shipping_cost) as avg_cost
              FROM shipments s
              JOIN sales_orders so ON s.sales_order_id = so.id 
              JOIN customers c ON so.customer_id = c.id
              $where_clause
              GROUP BY c.region
              ORDER BY total_cost DESC";

    $stmt = $pdo->prepare($query);
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    $stmt->execute();
    $cost_by_region = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 如果指定了订单ID，获取详细信息
    $order_details = null;
    if ($order_id > 0) {
        $query = "SELECT 
                    s.id,
                    s.shipment_number,
                    s.tracking_number,
                    s.shipment_date,
                    s.shipping_cost,
                    c.region,
                    c.name as customer_name,
                    cr.name as carrier_name,
                    so.order_number,
                    so.total_amount as order_amount,
                    (s.shipping_cost / so.total_amount * 100) as cost_percentage
                  FROM shipments s
                  JOIN sales_orders so ON s.sales_order_id = so.id
                  JOIN customers c ON so.customer_id = c.id
                  LEFT JOIN carriers cr ON s.carrier_id = cr.id
                  WHERE s.sales_order_id = :order_id
                  LIMIT 1";

        $stmt = $pdo->prepare($query);
        $stmt->bindValue(':order_id', $order_id);
        $stmt->execute();
        $order_details = $stmt->fetch(PDO::FETCH_ASSOC);
    }
} catch (PDOException $e) {
    $error = "数据库查询错误: " . $e->getMessage();
}

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($page_title) ?> - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <!-- <script src="https://cdn.bootcdn.net/ajax/libs/Chart.js/3.9.1/chart.min.js"></script> -->
    <script src="https://cdn.bootcdn.net/ajax/libs/chart.js/3.9.1/chart.min.js"></script>
    <style>
        /* 统计卡片样式 */
        .stats-cards {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .stats-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            text-align: center;
        }

        .stats-card h3 {
            margin: 0 0 10px;
            color: #666;
            font-size: 16px;
        }

        .stats-card .value {
            font-size: 32px;
            font-weight: bold;
            color: #2c3e50;
        }

        /* 选项卡样式 */
        .tabs {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab {
            padding: 12px 18px;
            cursor: pointer;
            font-weight: 500;
            transition: all 0.3s;
        }

        .tab:hover {
            background-color: #f8f9fa;
        }

        .tab.active {
            background-color: #3498db !important;
            color: white !important;
            border-radius: 0;
            display: block;
        }

        /* 选项卡内容区域 */
        .tab-content {
            display: none;
            padding: 20px 0;
        }

        .tab-content.active {
            display: block;
        }

        /* 图表容器样式 */
        .chart-container {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 30px;
        }

        .chart-container h2 {
            margin-top: 0;
            margin-bottom: 20px;
            font-size: 18px;
            color: #333;
        }

        .chart-wrapper {
            position: relative;
            height: 300px;
        }

        /* 表格容器样式 */
        .table-container {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 30px;
            overflow-x: auto;
        }

        .table-container h2 {
            margin-top: 0;
            margin-bottom: 20px;
            font-size: 18px;
            color: #333;
        }

        /* 订单详情样式 */
        .order-details-container {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 30px;
        }

        .order-details-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 20px;
            margin-bottom: 30px;
        }

        .detail-item {
            margin-bottom: 10px;
        }

        .detail-label {
            display: inline-block;
            width: 120px;
            font-weight: bold;
            color: #666;
        }

        .detail-value {
            font-weight: 500;
            color: #333;
        }

        /* 配送成本占比样式 */
        .cost-percentage {
            background-color: #f8f9fa;
            border-radius: 6px;
            padding: 20px;
            text-align: center;
        }

        .percentage {
            font-size: 36px;
            font-weight: bold;
            margin: 10px 0;
            color: #2c3e50;
        }

        .cost-gauge {
            width: 100%;
            height: 20px;
            background-color: #ecf0f1;
            border-radius: 10px;
            margin: 15px 0;
            overflow: hidden;
        }

        .cost-gauge-fill {
            height: 100%;
            background: linear-gradient(to right, #2ecc71, #f1c40f, #e74c3c);
            border-radius: 10px;
            transition: width 0.5s ease-in-out;
        }

        /* 筛选表单样式 */
        .filter-container {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 30px;
        }

        .search-bar {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            align-items: center;
        }

        .search-bar input,
        .search-bar select {
            padding: 8px 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            flex-grow: 1;
            min-width: 150px;
        }

        .search-bar button {
            padding: 8px 16px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background-color 0.3s;
        }

        .search-bar button:hover {
            background-color: #2980b9;
        }

        .btn-cancel {
            background-color: #95a5a6 !important;
        }

        .btn-cancel:hover {
            background-color: #7f8c8d !important;
        }

        @media (max-width: 768px) {
            .search-bar {
                flex-direction: column;
                align-items: stretch;
            }

            .search-bar input,
            .search-bar select,
            .search-bar button {
                width: 100%;
                margin-bottom: 10px;
            }

            .order-details-grid {
                grid-template-columns: 1fr;
            }
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>配送成本分析</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <!-- 筛选条件 -->
        <div class="filter-container">
            <form action="" method="GET" class="search-bar">
                <input type="date" name="date_from" value="<?= htmlspecialchars($date_from) ?>" title="起始日期">
                <input type="date" name="date_to" value="<?= htmlspecialchars($date_to) ?>" title="结束日期">

                <select name="carrier_id" title="物流公司">
                    <option value="0">所有物流公司</option>
                    <?php foreach ($carriers as $carrier): ?>
                        <option value="<?= $carrier['id'] ?>" <?= $carrier_id == $carrier['id'] ? 'selected' : '' ?>><?= htmlspecialchars($carrier['name']) ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="region" title="地区">
                    <option value="">所有地区</option>
                    <?php foreach ($regions as $r): ?>
                        <option value="<?= $r ?>" <?= $region == $r ? 'selected' : '' ?>><?= htmlspecialchars($r) ?></option>
                    <?php endforeach; ?>
                </select>

                <button type="submit">应用筛选</button>
                <button type="button" onclick="location.href='delivery_cost_analysis.php'" class="btn-cancel">重置</button>
            </form>
        </div>

        <!-- 统计卡片 -->
        <div class="stats-cards">
            <div class="stats-card">
                <h3>总订单数</h3>
                <div class="value"><?= number_format($total_shipments) ?></div>
            </div>
            <div class="stats-card">
                <h3>总配送成本</h3>
                <div class="value">¥<?= number_format($total_cost, 2) ?></div>
            </div>
            <div class="stats-card">
                <h3>平均配送成本</h3>
                <div class="value">¥<?= number_format($avg_cost, 2) ?></div>
            </div>
        </div>

        <!-- 选项卡 -->
        <div class="tabs">
            <div class="tab <?= $active_tab == 'overview' || empty($active_tab) ? 'active' : '' ?>" onclick="showTab('overview')">总体概览</div>
            <div class="tab <?= $active_tab == 'by-carrier' ? 'active' : '' ?>" onclick="showTab('by-carrier')">按物流公司</div>
            <div class="tab <?= $active_tab == 'by-region' ? 'active' : '' ?>" onclick="showTab('by-region')">按地区</div>
            <div class="tab <?= $active_tab == 'single-order' ? 'active' : '' ?>" onclick="showTab('single-order')">单笔订单分析</div>
        </div>

        <!-- 总体概览选项卡 -->
        <div id="overview" class="tab-content <?= $active_tab == 'overview' || empty($active_tab) ? 'active' : '' ?>">
            <!-- 月度成本趋势图 -->
            <div class="chart-container">
                <h2>月度配送成本趋势</h2>
                <div class="chart-wrapper">
                    <canvas id="monthlyCostChart"></canvas>
                </div>
            </div>

            <!-- 月度成本数据表 -->
            <div class="table-container">
                <h2>月度配送成本数据</h2>
                <?php if (empty($monthly_costs)): ?>
                    <p>暂无数据</p>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>月份</th>
                                <th>订单数量</th>
                                <th>总配送成本</th>
                                <th>平均配送成本</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($monthly_costs as $cost): ?>
                                <tr>
                                    <td><?= htmlspecialchars($cost['month']) ?></td>
                                    <td><?= number_format($cost['shipment_count']) ?></td>
                                    <td>¥<?= number_format($cost['total_cost'], 2) ?></td>
                                    <td>¥<?= number_format($cost['avg_cost'], 2) ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <!-- 按物流公司选项卡 -->
        <div id="by-carrier" class="tab-content <?= $active_tab == 'by-carrier' ? 'active' : '' ?>">
            <!-- 物流公司成本对比图 -->
            <div class="chart-container">
                <h2>物流公司配送成本对比</h2>
                <div class="chart-wrapper">
                    <canvas id="carrierCostChart"></canvas>
                </div>
            </div>

            <!-- 物流公司成本数据表 -->
            <div class="table-container">
                <h2>物流公司配送成本数据</h2>
                <?php if (empty($cost_by_carrier)): ?>
                    <p>暂无数据</p>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>物流公司</th>
                                <th>订单数量</th>
                                <th>总配送成本</th>
                                <th>平均配送成本</th>
                                <th>成本占比</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($cost_by_carrier as $cost): ?>
                                <?php $percentage = $total_cost > 0 ? ($cost['total_cost'] / $total_cost) * 100 : 0; ?>
                                <tr>
                                    <td><?= htmlspecialchars($cost['name']) ?></td>
                                    <td><?= number_format($cost['shipment_count']) ?></td>
                                    <td>¥<?= number_format($cost['total_cost'], 2) ?></td>
                                    <td>¥<?= number_format($cost['avg_cost'], 2) ?></td>
                                    <td><?= number_format($percentage, 2) ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <!-- 按地区选项卡 -->
        <div id="by-region" class="tab-content <?= $active_tab == 'by-region' ? 'active' : '' ?>">
            <!-- 地区成本对比图 -->
            <div class="chart-container">
                <h2>地区配送成本对比</h2>
                <div class="chart-wrapper">
                    <canvas id="regionCostChart"></canvas>
                </div>
            </div>

            <!-- 地区成本数据表 -->
            <div class="table-container">
                <h2>地区配送成本数据</h2>
                <?php if (empty($cost_by_region)): ?>
                    <p>暂无数据</p>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>地区</th>
                                <th>订单数量</th>
                                <th>总配送成本</th>
                                <th>平均配送成本</th>
                                <th>成本占比</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($cost_by_region as $cost): ?>
                                <?php $percentage = $total_cost > 0 ? ($cost['total_cost'] / $total_cost) * 100 : 0; ?>
                                <tr>
                                    <td><?= htmlspecialchars($cost['region']) ?></td>
                                    <td><?= number_format($cost['shipment_count']) ?></td>
                                    <td>¥<?= number_format($cost['total_cost'], 2) ?></td>
                                    <td>¥<?= number_format($cost['avg_cost'], 2) ?></td>
                                    <td><?= number_format($percentage, 2) ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <!-- 单笔订单分析选项卡 -->
        <div id="single-order" class="tab-content <?= $active_tab == 'single-order' ? 'active' : '' ?>">
            <!-- 订单查询 -->
            <div class="filter-container">
                <form action="" method="GET" class="search-bar">
                    <input type="hidden" name="tab" value="single-order">
                    <input type="number" name="order_id" placeholder="输入订单ID" value="<?= $order_id ?>" min="1" required>
                    <button type="submit">查询订单</button>
                </form>
            </div>

            <?php if ($order_id > 0): ?>
                <?php if ($order_details): ?>
                    <!-- 订单详情 -->
                    <div class="order-details-container">
                        <h2>订单配送成本分析</h2>
                        <div class="order-details-grid">
                            <div>
                                <div class="detail-item">
                                    <span class="detail-label">订单号</span>
                                    <span class="detail-value"><?= htmlspecialchars($order_details['order_number']) ?></span>
                                </div>
                                <div class="detail-item">
                                    <span class="detail-label">客户</span>
                                    <span class="detail-value"><?= htmlspecialchars($order_details['customer_name']) ?></span>
                                </div>
                                <div class="detail-item">
                                    <span class="detail-label">地区</span>
                                    <span class="detail-value"><?= htmlspecialchars($order_details['region']) ?></span>
                                </div>
                            </div>
                            <div>
                                <div class="detail-item">
                                    <span class="detail-label">发货单号</span>
                                    <span class="detail-value"><?= htmlspecialchars($order_details['shipment_number']) ?></span>
                                </div>
                                <div class="detail-item">
                                    <span class="detail-label">物流单号</span>
                                    <span class="detail-value"><?= htmlspecialchars($order_details['tracking_number'] ?: '未分配') ?></span>
                                </div>
                                <div class="detail-item">
                                    <span class="detail-label">物流公司</span>
                                    <span class="detail-value"><?= htmlspecialchars($order_details['carrier_name'] ?: '未指定') ?></span>
                                </div>
                            </div>
                            <div>
                                <div class="detail-item">
                                    <span class="detail-label">发货日期</span>
                                    <span class="detail-value"><?= date('Y-m-d', strtotime($order_details['shipment_date'])) ?></span>
                                </div>
                                <div class="detail-item">
                                    <span class="detail-label">订单金额</span>
                                    <span class="detail-value">¥<?= number_format($order_details['order_amount'], 2) ?></span>
                                </div>
                                <div class="detail-item">
                                    <span class="detail-label">配送费用</span>
                                    <span class="detail-value">¥<?= number_format($order_details['shipping_cost'], 2) ?></span>
                                </div>
                            </div>
                        </div>

                        <!-- 配送成本占比 -->
                        <div class="cost-percentage">
                            <div>配送成本占订单金额比例</div>
                            <div class="percentage"><?= number_format($order_details['cost_percentage'], 2) ?>%</div>
                            <div class="cost-gauge">
                                <div class="cost-gauge-fill" style="width: <?= min($order_details['cost_percentage'] * 2, 100) ?>%;"></div>
                            </div>
                            <?php
                            if ($order_details['cost_percentage'] < 5) {
                                echo '<p>配送成本占比合理，物流效率较高</p>';
                            } elseif ($order_details['cost_percentage'] < 15) {
                                echo '<p>配送成本占比处于正常范围</p>';
                            } else {
                                echo '<p>配送成本占比较高，建议优化物流策略</p>';
                            }
                            ?>
                        </div>
                    </div>

                    <!-- 成本优化建议 -->
                    <div class="table-container">
                        <h2>配送成本优化建议</h2>
                        <table>
                            <thead>
                                <tr>
                                    <th>优化项目</th>
                                    <th>建议</th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr>
                                    <td>物流公司选择</td>
                                    <td>
                                        <?php
                                        $avg_cost_current_carrier = 0;
                                        foreach ($cost_by_carrier as $c) {
                                            if ($c['name'] == $order_details['carrier_name']) {
                                                $avg_cost_current_carrier = $c['avg_cost'];
                                                break;
                                            }
                                        }

                                        $better_carriers = [];
                                        foreach ($cost_by_carrier as $c) {
                                            if ($c['avg_cost'] < $avg_cost_current_carrier && $c['name'] != $order_details['carrier_name']) {
                                                $better_carriers[] = $c;
                                            }
                                        }

                                        if (!empty($better_carriers)) {
                                            echo "考虑使用平均成本更低的物流公司：";
                                            $c_names = array_map(function ($c) {
                                                return $c['name'] . " (¥" . number_format($c['avg_cost'], 2) . ")";
                                            }, $better_carriers);
                                            echo implode(", ", $c_names);
                                        } else {
                                            echo "当前物流公司在成本方面表现良好";
                                        }
                                        ?>
                                    </td>
                                </tr>
                                <tr>
                                    <td>发货时间</td>
                                    <td>
                                        <?php
                                        $month = date('Y-m', strtotime($order_details['shipment_date']));
                                        $is_peak = false;
                                        foreach ($monthly_costs as $m) {
                                            if ($m['month'] == $month && $m['avg_cost'] > $avg_cost) {
                                                $is_peak = true;
                                                break;
                                            }
                                        }

                                        if ($is_peak) {
                                            echo "该订单发货在物流成本高峰期，考虑调整非紧急订单的发货时间";
                                        } else {
                                            echo "发货时间选择合理，不在物流成本高峰期";
                                        }
                                        ?>
                                    </td>
                                </tr>
                                <tr>
                                    <td>订单批量</td>
                                    <td>
                                        <?php
                                        if ($order_details['order_amount'] < 500) {
                                            echo "小额订单配送成本占比较高，考虑合并订单或设置最低订单金额要求";
                                        } else {
                                            echo "订单金额合理，适合单独配送";
                                        }
                                        ?>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                <?php else: ?>
                    <div class="alert alert-danger">未找到订单信息，请确认订单ID是否正确</div>
                <?php endif; ?>
            <?php else: ?>
                <div class="table-container">
                    <h2>单笔订单配送成本分析</h2>
                    <p>请输入订单ID查询详细的配送成本分析</p>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 页面加载完成后初始化图表
        document.addEventListener('DOMContentLoaded', function() {
            // 初始化图表
            initCharts();

            // 如果URL中有tab参数，切换到对应选项卡
            const urlParams = new URLSearchParams(window.location.search);
            const tabParam = urlParams.get('tab');
            if (tabParam) {
                showTab(tabParam);
            }
        });

        // 切换选项卡
        function showTab(tabId) {
            // 隐藏所有选项卡内容
            document.querySelectorAll('.tab-content').forEach(function(tab) {
                tab.classList.remove('active');
            });

            // 取消所有选项卡的选中状态
            document.querySelectorAll('.tab').forEach(function(tab) {
                tab.classList.remove('active');
            });

            // 显示选中的选项卡内容
            document.getElementById(tabId).classList.add('active');

            // 设置选项卡按钮为选中状态 - 使用精确匹配
            document.querySelectorAll('.tabs .tab').forEach(function(tab) {
                // 使用精确匹配
                if ((tab.innerText.trim() === '总体概览' && tabId === 'overview') ||
                    (tab.innerText.trim() === '按物流公司' && tabId === 'by-carrier') ||
                    (tab.innerText.trim() === '按地区' && tabId === 'by-region') ||
                    (tab.innerText.trim() === '单笔订单分析' && tabId === 'single-order')) {
                    tab.classList.add('active');
                }
            });

            // 更新URL参数，但不刷新页面
            const url = new URL(window.location);
            url.searchParams.set('tab', tabId);
            window.history.pushState({}, '', url);
        }

        // 初始化图表
        function initCharts() {
            // 月度成本趋势图
            const monthlyCostCtx = document.getElementById('monthlyCostChart').getContext('2d');
            const monthlyCostChart = new Chart(monthlyCostCtx, {
                type: 'line',
                data: {
                    labels: <?= json_encode(array_column($monthly_costs, 'month')) ?>,
                    datasets: [{
                            label: '总配送成本',
                            data: <?= json_encode(array_column($monthly_costs, 'total_cost')) ?>,
                            borderColor: '#3498db',
                            backgroundColor: 'rgba(52, 152, 219, 0.2)',
                            fill: true,
                            tension: 0.4
                        },
                        {
                            label: '平均配送成本',
                            data: <?= json_encode(array_column($monthly_costs, 'avg_cost')) ?>,
                            borderColor: '#e74c3c',
                            backgroundColor: 'rgba(231, 76, 60, 0.2)',
                            borderDash: [5, 5],
                            fill: false,
                            tension: 0.4
                        }
                    ]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            beginAtZero: true,
                            title: {
                                display: true,
                                text: '金额 (¥)'
                            }
                        },
                        x: {
                            title: {
                                display: true,
                                text: '月份'
                            }
                        }
                    },
                    plugins: {
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    let label = context.dataset.label || '';
                                    if (label) {
                                        label += ': ';
                                    }
                                    if (context.parsed.y !== null) {
                                        label += '¥' + context.parsed.y.toFixed(2);
                                    }
                                    return label;
                                }
                            }
                        }
                    }
                }
            });

            // 物流公司成本对比图
            const carrierCostCtx = document.getElementById('carrierCostChart').getContext('2d');
            const carrierCostChart = new Chart(carrierCostCtx, {
                type: 'bar',
                data: {
                    labels: <?= json_encode(array_column($cost_by_carrier, 'name')) ?>,
                    datasets: [{
                        label: '平均配送成本',
                        data: <?= json_encode(array_column($cost_by_carrier, 'avg_cost')) ?>,
                        backgroundColor: 'rgba(52, 152, 219, 0.7)',
                        borderColor: 'rgba(52, 152, 219, 1)',
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            beginAtZero: true,
                            title: {
                                display: true,
                                text: '平均配送成本 (¥)'
                            }
                        },
                        x: {
                            title: {
                                display: true,
                                text: '物流公司'
                            }
                        }
                    },
                    plugins: {
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    let label = context.dataset.label || '';
                                    if (label) {
                                        label += ': ';
                                    }
                                    if (context.parsed.y !== null) {
                                        label += '¥' + context.parsed.y.toFixed(2);
                                    }
                                    return label;
                                }
                            }
                        }
                    }
                }
            });

            // 地区成本对比图
            const regionCostCtx = document.getElementById('regionCostChart').getContext('2d');
            const regionCostChart = new Chart(regionCostCtx, {
                type: 'bar',
                data: {
                    labels: <?= json_encode(array_column($cost_by_region, 'region')) ?>,
                    datasets: [{
                        label: '平均配送成本',
                        data: <?= json_encode(array_column($cost_by_region, 'avg_cost')) ?>,
                        backgroundColor: 'rgba(46, 204, 113, 0.7)',
                        borderColor: 'rgba(46, 204, 113, 1)',
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            beginAtZero: true,
                            title: {
                                display: true,
                                text: '平均配送成本 (¥)'
                            }
                        },
                        x: {
                            title: {
                                display: true,
                                text: '地区'
                            }
                        }
                    },
                    plugins: {
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    let label = context.dataset.label || '';
                                    if (label) {
                                        label += ': ';
                                    }
                                    if (context.parsed.y !== null) {
                                        label += '¥' + context.parsed.y.toFixed(2);
                                    }
                                    return label;
                                }
                            }
                        }
                    }
                }
            });
        }
    </script>
</body>

</html>