<?php
// quality/product_testing.php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取完成质检的批次列表
$completedBatches = [];
try {
    $stmt = $pdo->prepare("
        SELECT pb.id, pb.batch_number, pb.end_time, p.name AS product_name,
               p.type AS product_type, pb.status, 
               (SELECT COUNT(*) FROM qc_finished_goods_tests qc WHERE qc.production_batch_id = pb.id) AS test_count
        FROM production_batches pb
        JOIN products p ON pb.product_id = p.id
        WHERE pb.status = 'completed' OR pb.status = 'quality_check' OR pb.status = 'stocked'
        ORDER BY pb.end_time DESC
        LIMIT 50
    ");
    $stmt->execute();
    $completedBatches = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取批次数据失败: " . $e->getMessage();
}

// 处理检测数据添加请求
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'add_test') {
    $batch_id = $_POST['batch_id'] ?? 0;
    $product_id = $_POST['product_id'] ?? 0;
    $test_name = $_POST['test_name'] ?? '';
    $test_standard = $_POST['test_standard'] ?? '';
    $test_result_value = $_POST['test_result_value'] ?? '';
    $result = $_POST['result'] ?? '';
    $notes = $_POST['notes'] ?? '';

    if ($batch_id && $product_id && $test_name && $result) {
        try {
            $stmt = $pdo->prepare("
                INSERT INTO qc_finished_goods_tests 
                (production_batch_id, product_id, test_name, test_standard, test_result_value, result, test_date, tester_id, notes)
                VALUES (?, ?, ?, ?, ?, ?, NOW(), ?, ?)
            ");
            $stmt->execute([
                $batch_id,
                $product_id,
                $test_name,
                $test_standard,
                $test_result_value,
                $result,
                $_SESSION['user_id'],
                $notes
            ]);

            // 更新批次状态为已质检
            if ($result === 'passed') {
                $stmt = $pdo->prepare("
                    UPDATE production_batches 
                    SET status = 'quality_check' 
                    WHERE id = ? AND status = 'completed'
                ");
                $stmt->execute([$batch_id]);
            }

            $_SESSION['success'] = "检测数据已添加";

            // 记录到操作日志
            $stmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, details, ip_address) 
                VALUES (?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $_SESSION['user_id'],
                $_SESSION['username'],
                '添加成品检测记录',
                'production_batch',
                $batch_id,
                json_encode([
                    'test_name' => $test_name,
                    'result' => $result,
                    'test_result_value' => $test_result_value
                ]),
                $_SERVER['REMOTE_ADDR']
            ]);

            header("Location: product_testing.php?batch_id=" . $batch_id);
            exit;
        } catch (PDOException $e) {
            $error = "添加检测数据失败: " . $e->getMessage();
        }
    } else {
        $error = "请提供所有必要信息";
    }
}

// 获取选定批次的检测记录
$batchId = $_GET['batch_id'] ?? null;
$testData = [];
$batchInfo = null;

if ($batchId) {
    try {
        // 获取检测记录
        $stmt = $pdo->prepare("
            SELECT qc.*, u.username AS tester_name, pb.batch_number, p.name AS product_name,
                  pb.product_id, pb.status AS batch_status
            FROM qc_finished_goods_tests qc
            JOIN users u ON qc.tester_id = u.id
            JOIN production_batches pb ON qc.production_batch_id = pb.id
            JOIN products p ON qc.product_id = p.id
            WHERE qc.production_batch_id = ?
            ORDER BY qc.test_date DESC
        ");
        $stmt->execute([$batchId]);
        $testData = $stmt->fetchAll();

        // 获取批次信息
        $stmt = $pdo->prepare("
            SELECT pb.batch_number, p.name AS product_name, p.id AS product_id,
                   pb.quantity_produced, pb.start_time, pb.end_time, pb.status,
                   p.unit, p.specification
            FROM production_batches pb
            JOIN products p ON pb.product_id = p.id
            WHERE pb.id = ?
        ");
        $stmt->execute([$batchId]);
        $batchInfo = $stmt->fetch();
    } catch (PDOException $e) {
        $error = "获取检测数据失败: " . $e->getMessage();
    }
}

// 检测项目定义
$testItems = [
    '口感检测' => [
        '标准' => '口感酥脆，有水果香气，不过硬，不粘牙',
        '方法' => '感官评定，品尝测试'
    ],
    '色泽检测' => [
        '标准' => '色泽均匀，符合产品特性，无异常变色',
        '方法' => '目视检查，光度计测量'
    ],
    '水分含量检测' => [
        '标准' => '水分含量在8%-15%之间',
        '方法' => '烘干法测定'
    ],
    '包装完整性' => [
        '标准' => '包装完好，密封良好，无破损',
        '方法' => '视觉检查，密封测试'
    ],
    '重量检测' => [
        '标准' => '实际重量与标示重量误差在±3%以内',
        '方法' => '精密天平称重'
    ]
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>成品检测 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .test-stats {
            display: flex;
            justify-content: space-between;
            margin-bottom: 20px;
        }

        .stat-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 15px;
            width: 32%;
            text-align: center;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            margin: 10px 0;
        }

        .stat-label {
            font-size: 14px;
            color: #666;
        }

        .passed {
            color: #2ecc71;
        }

        .failed {
            color: #e74c3c;
        }

        .pending {
            color: #f39c12;
        }

        .test-tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab-button {
            padding: 10px 20px;
            background: none;
            border: none;
            cursor: pointer;
            font-size: 16px;
            border-bottom: 3px solid transparent;
            transition: all 0.3s;
        }

        .tab-button.active {
            border-bottom-color: #e74c3c;
            color: #e74c3c;
            font-weight: bold;
        }

        .tab-button:hover:not(.active) {
            border-bottom-color: #bdc3c7;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .test-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            color: white;
        }

        .test-passed {
            background-color: #2ecc71;
        }

        .test-failed {
            background-color: #e74c3c;
        }

        .test-form {
            background-color: #f9f9f9;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
        }

        .form-row {
            display: flex;
            margin-bottom: 15px;
        }

        .form-group {
            flex: 1;
            margin-right: 15px;
        }

        .form-group:last-child {
            margin-right: 0;
        }

        .test-item {
            margin-bottom: 15px;
            padding: 15px;
            border-radius: 8px;
            background-color: #fff;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        .test-item-header {
            display: flex;
            justify-content: space-between;
            margin-bottom: 10px;
        }

        .test-item-name {
            font-weight: bold;
            font-size: 16px;
        }

        .test-details {
            margin-top: 10px;
            padding-top: 10px;
            border-top: 1px dashed #ddd;
        }

        .test-details p {
            margin: 5px 0;
        }

        .batch-selector {
            margin-bottom: 20px;
        }

        .batch-info {
            background-color: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .batch-info-grid {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 10px;
        }

        .info-item {
            margin-bottom: 10px;
        }

        .info-label {
            font-weight: bold;
            color: #666;
        }

        .standards-table {
            margin-top: 20px;
        }

        .result-chart {
            height: 300px;
            margin: 20px 0;
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 10px;
            background-color: #fff;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>成品检测管理</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-error"><?= $error ?></div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <!-- 批次选择 -->
        <div class="batch-selector">
            <form method="get" action="product_testing.php" class="form-row">
                <div class="form-group">
                    <label>选择生产批次</label>
                    <select name="batch_id" class="form-control" onchange="this.form.submit()">
                        <option value="">-- 请选择批次 --</option>
                        <?php foreach ($completedBatches as $batch): ?>
                            <option value="<?= $batch['id'] ?>" <?= $batchId == $batch['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($batch['batch_number']) ?> - <?= htmlspecialchars($batch['product_name']) ?>
                                (<?= $batch['test_count'] ? '已检测' : '未检测' ?>)
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </form>
        </div>

        <?php if (empty($completedBatches)): ?>
            <div class="alert alert-info">当前没有已完成的生产批次，请先在生产管理中完成批次生产。</div>
        <?php elseif ($batchId && $batchInfo): ?>
            <!-- 批次信息 -->
            <div class="batch-info">
                <h3>批次信息 - <?= htmlspecialchars($batchInfo['batch_number']) ?></h3>
                <div class="batch-info-grid">
                    <div class="info-item">
                        <div class="info-label">产品名称</div>
                        <div><?= htmlspecialchars($batchInfo['product_name']) ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">规格</div>
                        <div><?= htmlspecialchars($batchInfo['specification'] ?: '-') ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">产量</div>
                        <div><?= number_format($batchInfo['quantity_produced'], 2) ?> <?= htmlspecialchars($batchInfo['unit']) ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">生产开始时间</div>
                        <div><?= date('Y-m-d H:i', strtotime($batchInfo['start_time'])) ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">生产结束时间</div>
                        <div><?= date('Y-m-d H:i', strtotime($batchInfo['end_time'])) ?></div>
                    </div>
                    <div class="info-item">
                        <div class="info-label">当前状态</div>
                        <div>
                            <?php
                            $statusText = '';
                            switch ($batchInfo['status']) {
                                case 'completed':
                                    $statusText = '生产完成';
                                    break;
                                case 'quality_check':
                                    $statusText = '质检中';
                                    break;
                                case 'stocked':
                                    $statusText = '已入库';
                                    break;
                                default:
                                    $statusText = $batchInfo['status'];
                            }
                            echo $statusText;
                            ?>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 检测标签页 -->
            <div class="test-tabs">
                <button class="tab-button active" onclick="showTab('test-results-tab')">检测结果</button>
                <button class="tab-button" onclick="showTab('add-test-tab')">添加检测</button>
                <button class="tab-button" onclick="showTab('standards-tab')">检测标准</button>
            </div>

            <!-- 检测结果标签内容 -->
            <div id="test-results-tab" class="tab-content active">
                <!-- 统计卡片 -->
                <?php
                $passedCount = 0;
                $failedCount = 0;
                $totalCount = count($testData);

                foreach ($testData as $test) {
                    if ($test['result'] === 'passed') {
                        $passedCount++;
                    } else {
                        $failedCount++;
                    }
                }
                $passRate = $totalCount > 0 ? round(($passedCount / $totalCount) * 100, 1) : 0;
                ?>
                <div class="test-stats">
                    <div class="stat-card">
                        <div class="stat-value passed"><?= $passedCount ?></div>
                        <div class="stat-label">合格检测项</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-value failed"><?= $failedCount ?></div>
                        <div class="stat-label">不合格检测项</div>
                    </div>
                    <div class="stat-card">
                        <div class="stat-value"><?= $passRate ?>%</div>
                        <div class="stat-label">检测合格率</div>
                    </div>
                </div>

                <?php if (empty($testData)): ?>
                    <div class="alert alert-info">该批次尚未进行任何检测，请添加检测记录。</div>
                <?php else: ?>
                    <!-- 检测结果列表 -->
                    <?php foreach ($testData as $test): ?>
                        <div class="test-item">
                            <div class="test-item-header">
                                <div class="test-item-name"><?= htmlspecialchars($test['test_name']) ?></div>
                                <div>
                                    <span class="test-tag <?= $test['result'] === 'passed' ? 'test-passed' : 'test-failed' ?>">
                                        <?= $test['result'] === 'passed' ? '合格' : '不合格' ?>
                                    </span>
                                </div>
                            </div>
                            <div class="test-details">
                                <p><strong>检测标准:</strong> <?= htmlspecialchars($test['test_standard']) ?></p>
                                <p><strong>检测结果:</strong> <?= htmlspecialchars($test['test_result_value']) ?></p>
                                <p><strong>检测时间:</strong> <?= date('Y-m-d H:i', strtotime($test['test_date'])) ?></p>
                                <p><strong>检测人员:</strong> <?= htmlspecialchars($test['tester_name']) ?></p>
                                <?php if (!empty($test['notes'])): ?>
                                    <p><strong>备注:</strong> <?= htmlspecialchars($test['notes']) ?></p>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>

            <!-- 添加检测标签内容 -->
            <div id="add-test-tab" class="tab-content">
                <div class="test-form">
                    <h3>添加检测记录</h3>
                    <form method="POST" action="product_testing.php">
                        <input type="hidden" name="action" value="add_test">
                        <input type="hidden" name="batch_id" value="<?= $batchId ?>">
                        <input type="hidden" name="product_id" value="<?= $batchInfo['product_id'] ?>">

                        <div class="form-row">
                            <div class="form-group">
                                <label>检测项目</label>
                                <select name="test_name" class="form-control" required onchange="updateStandard(this.value)">
                                    <option value="">-- 请选择 --</option>
                                    <?php foreach ($testItems as $item => $details): ?>
                                        <option value="<?= $item ?>"><?= $item ?></option>
                                    <?php endforeach; ?>
                                    <option value="其他">其他项目</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label>检测标准</label>
                                <input type="text" name="test_standard" id="test_standard" class="form-control" required>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-group">
                                <label>检测结果值</label>
                                <input type="text" name="test_result_value" class="form-control" required>
                            </div>

                            <div class="form-group">
                                <label>检测结论</label>
                                <select name="result" class="form-control" required>
                                    <option value="">-- 请选择 --</option>
                                    <option value="passed">合格</option>
                                    <option value="failed">不合格</option>
                                </select>
                            </div>
                        </div>

                        <div class="form-group">
                            <label>备注</label>
                            <textarea name="notes" class="form-control" rows="3"></textarea>
                        </div>

                        <div class="form-group">
                            <button type="submit" class="btn-primary">提交检测结果</button>
                        </div>
                    </form>
                </div>
            </div>

            <!-- 检测标准标签内容 -->
            <div id="standards-tab" class="tab-content">
                <div class="standards-table">
                    <h3>成品检测标准</h3>
                    <table>
                        <thead>
                            <tr>
                                <th>检测项目</th>
                                <th>检测标准</th>
                                <th>检测方法</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($testItems as $item => $details): ?>
                                <tr>
                                    <td><?= htmlspecialchars($item) ?></td>
                                    <td><?= htmlspecialchars($details['标准']) ?></td>
                                    <td><?= htmlspecialchars($details['方法']) ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>

                    <h3 class="mt-4">成品质量问题对照表</h3>
                    <table>
                        <thead>
                            <tr>
                                <th>常见问题</th>
                                <th>可能原因</th>
                                <th>处理方式</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td>水分含量过高</td>
                                <td>烘干不充分、储存湿度过高</td>
                                <td>调整烘干温度和时间，检查储存环境湿度</td>
                            </tr>
                            <tr>
                                <td>色泽不均匀</td>
                                <td>原料成熟度不一、加工温度不均</td>
                                <td>加强原料筛选，改进加工工艺</td>
                            </tr>
                            <tr>
                                <td>口感过硬/过软</td>
                                <td>烘干时间过长/过短、配料比例不当</td>
                                <td>调整烘干参数，优化配方</td>
                            </tr>
                            <tr>
                                <td>包装破损</td>
                                <td>设备故障、操作不当</td>
                                <td>包装设备维护、操作培训</td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>
        <?php elseif ($batchId && !$batchInfo): ?>
            <div class="alert alert-error">未找到指定批次信息，请重新选择</div>
        <?php endif; ?>
    </div>

    <script>
        // 显示选定的标签页
        function showTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(tab => {
                tab.classList.remove('active');
            });

            // 移除所有标签按钮的激活状态
            document.querySelectorAll('.tab-button').forEach(button => {
                button.classList.remove('active');
            });

            // 激活选定的标签
            document.getElementById(tabId).classList.add('active');

            // 激活对应的按钮
            event.currentTarget.classList.add('active');
        }

        // 更新检测标准
        function updateStandard(testName) {
            const standards = {
                '口感检测': '口感酥脆，有水果香气，不过硬，不粘牙',
                '色泽检测': '色泽均匀，符合产品特性，无异常变色',
                '水分含量检测': '水分含量在8%-15%之间',
                '包装完整性': '包装完好，密封良好，无破损',
                '重量检测': '实际重量与标示重量误差在±3%以内'
            };

            // 更新标准值输入框
            const standardInput = document.getElementById('test_standard');
            if (standards[testName]) {
                standardInput.value = standards[testName];
            } else {
                standardInput.value = '';
            }
        }
    </script>
</body>

</html>