<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$success = '';
$products = [];
$filteredProducts = [];

// 检查必要的表是否存在
try {
    // 检查product_pricing表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'product_pricing'");
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $pdo->exec("
            CREATE TABLE IF NOT EXISTS `product_pricing` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '价格ID',
              `product_id` INT UNSIGNED NOT NULL COMMENT '产品ID',
              `wholesale_price` DECIMAL(10, 2) DEFAULT NULL COMMENT '批发价',
              `retail_price` DECIMAL(10, 2) DEFAULT NULL COMMENT '零售价',
              `promotion_discount` DECIMAL(5, 4) DEFAULT 0.0000 COMMENT '促销折扣率 (例如 0.1 表示 10% off)',
              `promotion_start_date` DATE DEFAULT NULL COMMENT '促销开始日期',
              `promotion_end_date` DATE DEFAULT NULL COMMENT '促销结束日期',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              UNIQUE KEY `uk_product_pricing` (`product_id`),
              CONSTRAINT `fk_pricing_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE CASCADE
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='产品价格表'
        ");

        // 初始化现有产品的价格数据
        $pdo->exec("
            INSERT INTO product_pricing (product_id, wholesale_price, retail_price)
            SELECT id, standard_price * 0.7, standard_price
            FROM products 
            WHERE type = 'finished' AND standard_price IS NOT NULL
        ");

        $success = "已创建产品价格表并初始化数据。";
    }
} catch (PDOException $e) {
    $error = "检查或创建数据表失败: " . $e->getMessage();
}

// 处理批量更新价格
if (isset($_POST['update_prices']) && isset($_POST['product_ids'])) {
    try {
        $pdo->beginTransaction();

        $product_ids = $_POST['product_ids'];
        $wholesale_prices = $_POST['wholesale_price'];
        $retail_prices = $_POST['retail_price'];

        $updated = 0;

        foreach ($product_ids as $index => $product_id) {
            if (isset($wholesale_prices[$index]) && isset($retail_prices[$index])) {
                $wholesale_price = floatval($wholesale_prices[$index]);
                $retail_price = floatval($retail_prices[$index]);

                // 检查产品价格记录是否存在
                $stmt = $pdo->prepare("SELECT id FROM product_pricing WHERE product_id = ?");
                $stmt->execute([$product_id]);

                if ($stmt->rowCount() > 0) {
                    // 更新现有记录
                    $stmt = $pdo->prepare("
                        UPDATE product_pricing 
                        SET wholesale_price = ?, retail_price = ?, updated_at = NOW() 
                        WHERE product_id = ?
                    ");
                    $stmt->execute([$wholesale_price, $retail_price, $product_id]);
                } else {
                    // 创建新记录
                    $stmt = $pdo->prepare("
                        INSERT INTO product_pricing (product_id, wholesale_price, retail_price) 
                        VALUES (?, ?, ?)
                    ");
                    $stmt->execute([$product_id, $wholesale_price, $retail_price]);
                }

                $updated++;
            }
        }

        $pdo->commit();
        $success = "已成功更新 {$updated} 个产品的价格信息。";
    } catch (PDOException $e) {
        $pdo->rollBack();
        $error = "更新价格失败: " . $e->getMessage();
    }
}

// 处理设置促销
if (isset($_POST['set_promotion'])) {
    $product_id = isset($_POST['promotion_product_id']) ? (int)$_POST['promotion_product_id'] : 0;
    $discount = isset($_POST['promotion_discount']) ? (float)$_POST['promotion_discount'] / 100 : 0;
    $start_date = isset($_POST['promotion_start_date']) ? $_POST['promotion_start_date'] : null;
    $end_date = isset($_POST['promotion_end_date']) ? $_POST['promotion_end_date'] : null;

    if ($product_id <= 0) {
        $error = "请选择有效的产品";
    } elseif ($discount <= 0 || $discount >= 1) {
        $error = "请输入有效的折扣率(1-99%)";
    } elseif (empty($start_date) || empty($end_date)) {
        $error = "请设置促销开始和结束日期";
    } elseif ($start_date > $end_date) {
        $error = "促销结束日期必须晚于开始日期";
    } else {
        try {
            $stmt = $pdo->prepare("
                UPDATE product_pricing 
                SET promotion_discount = ?, 
                    promotion_start_date = ?, 
                    promotion_end_date = ?,
                    updated_at = NOW()
                WHERE product_id = ?
            ");
            $stmt->execute([$discount, $start_date, $end_date, $product_id]);

            if ($stmt->rowCount() > 0) {
                $success = "促销设置成功，折扣率：" . ($discount * 100) . "%";
            } else {
                $error = "该产品不存在价格记录，请先设置基本价格";
            }
        } catch (PDOException $e) {
            $error = "设置促销失败: " . $e->getMessage();
        }
    }
}

// 取消促销
if (isset($_GET['cancel_promotion'])) {
    $product_id = (int)$_GET['cancel_promotion'];

    try {
        $stmt = $pdo->prepare("
            UPDATE product_pricing 
            SET promotion_discount = 0, 
                promotion_start_date = NULL, 
                promotion_end_date = NULL,
                updated_at = NOW()
            WHERE product_id = ?
        ");
        $stmt->execute([$product_id]);

        if ($stmt->rowCount() > 0) {
            $success = "已取消产品促销";
        } else {
            $error = "取消促销失败，该产品可能不存在价格记录";
        }
    } catch (PDOException $e) {
        $error = "取消促销失败: " . $e->getMessage();
    }
}

// 获取查询参数
$product_type = isset($_GET['product_type']) ? $_GET['product_type'] : 'finished';
$keyword = isset($_GET['keyword']) ? trim($_GET['keyword']) : '';
$show_promotion_only = isset($_GET['promotion_only']) && $_GET['promotion_only'] == '1';

// 获取所有产品和价格信息
try {
    $query = "
        SELECT 
            p.id,
            p.name,
            p.type,
            p.specification,
            p.unit,
            p.standard_price,
            pp.wholesale_price,
            pp.retail_price,
            pp.promotion_discount,
            pp.promotion_start_date,
            pp.promotion_end_date
        FROM 
            products p
        LEFT JOIN 
            product_pricing pp ON p.id = pp.product_id
        WHERE 
            p.type = ? 
    ";

    $params = [$product_type];

    if (!empty($keyword)) {
        $query .= " AND (p.name LIKE ? OR p.specification LIKE ?)";
        $params[] = "%$keyword%";
        $params[] = "%$keyword%";
    }

    if ($show_promotion_only) {
        $query .= " AND pp.promotion_discount > 0 AND pp.promotion_end_date >= CURDATE()";
    }

    $query .= " ORDER BY p.name";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取产品数据失败: " . $e->getMessage();
}

// 计算当前促销产品数量
$promotion_count = 0;
foreach ($products as $product) {
    if (!empty($product['promotion_discount']) && $product['promotion_discount'] > 0 && $product['promotion_end_date'] >= date('Y-m-d')) {
        $promotion_count++;
    }
}

// 产品类型映射
$product_type_map = [
    'raw' => '原料',
    'semi-finished' => '半成品',
    'finished' => '成品'
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>销售价格管理 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式优化 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .form-group input[type="text"],
        .form-group input[type="number"],
        .form-group input[type="date"],
        .form-group select {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            background-color: #fff;
            box-sizing: border-box;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .form-group input:focus,
        .form-group select:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        /* 搜索表单 */
        .search-form {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            margin-bottom: 20px;
            align-items: flex-end;
        }

        .search-form .form-group {
            margin-bottom: 0;
            flex: 1;
            min-width: 150px;
        }

        .search-form .btn,
        .search-form .btn-secondary {
            height: 42px;
            margin-bottom: 0;
            line-height: 22px;
            display: flex;
            align-items: center;
            justify-content: center;
            min-width: 80px;
            padding: 0 15px;
            font-size: 14px;
            font-weight: bold;
        }

        /* 按钮样式 */
        .btn,
        .btn-primary {
            padding: 10px 15px;
            background: #3498db;
            color: white !important;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
            text-decoration: none !important;
            display: inline-block;
            transition: background 0.3s;
        }

        .btn:hover,
        .btn-primary:hover {
            background: #2980b9;
        }

        .btn-secondary {
            background: #6c757d;
        }

        .btn-secondary:hover {
            background: #5a6268;
        }

        .btn-success {
            background: #28a745;
        }

        .btn-success:hover {
            background: #218838;
        }

        .btn-danger {
            background: #dc3545;
        }

        .btn-danger:hover {
            background: #c82333;
        }

        .btn-sm {
            padding: 5px 10px;
            font-size: 12px;
        }

        /* 表格样式 */
        .table-container {
            overflow-x: auto;
            margin-top: 20px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            font-size: 14px;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
            position: sticky;
            top: 0;
        }

        table tr:last-child td {
            border-bottom: none;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        table input[type="number"] {
            width: 100px;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
            text-align: right;
        }

        table input[type="number"]:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        /* 警告和成功消息 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* 空状态 */
        .empty-state {
            text-align: center;
            padding: 40px 20px;
            background: #f8f9fa;
            border-radius: 8px;
            border: 1px dashed #ddd;
            color: #6c757d;
        }

        .empty-state p {
            margin: 0;
            font-size: 16px;
        }

        /* 促销标签 */
        .promotion-tag {
            display: inline-block;
            padding: 3px 6px;
            background-color: #f39c12;
            color: white;
            border-radius: 3px;
            font-size: 12px;
            font-weight: bold;
        }

        /* 模态对话框 */
        .modal {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
            z-index: 1000;
            overflow: auto;
        }

        .modal-content {
            background-color: #fefefe;
            margin: 10% auto;
            padding: 20px;
            border-radius: 8px;
            width: 80%;
            max-width: 500px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        .modal-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        .modal-header h3 {
            margin: 0;
            font-size: 20px;
        }

        .modal-close {
            cursor: pointer;
            font-size: 24px;
            color: #aaa;
        }

        .modal-close:hover {
            color: #000;
        }

        .modal-footer {
            border-top: 1px solid #eee;
            padding-top: 15px;
            margin-top: 20px;
            text-align: right;
        }

        .modal-footer .btn {
            margin-left: 10px;
        }

        /* 价格显示样式 */
        .price-display {
            font-weight: bold;
        }

        .price-display.discounted {
            color: #dc3545;
        }

        .original-price {
            text-decoration: line-through;
            color: #6c757d;
            font-size: 0.9em;
        }

        /* 统计指标卡片 */
        .stats-container {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .stat-card {
            flex: 1;
            min-width: 200px;
            background: white;
            padding: 15px;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.05);
            text-align: center;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            color: #3498db;
            margin: 10px 0;
        }

        .stat-label {
            color: #555;
            font-size: 14px;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>销售价格管理</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <!-- 统计卡片 -->
        <div class="stats-container">
            <div class="stat-card">
                <div class="stat-label">产品总数</div>
                <div class="stat-value"><?= count($products) ?></div>
                <div class="stat-label">个<?= $product_type_map[$product_type] ?></div>
            </div>

            <div class="stat-card">
                <div class="stat-label">促销产品</div>
                <div class="stat-value"><?= $promotion_count ?></div>
                <div class="stat-label">个正在促销</div>
            </div>

            <div class="stat-card">
                <div class="stat-label">平均零售价</div>
                <div class="stat-value">
                    <?php
                    $total_price = 0;
                    $price_count = 0;
                    foreach ($products as $product) {
                        if (!empty($product['retail_price'])) {
                            $total_price += $product['retail_price'];
                            $price_count++;
                        }
                    }
                    echo $price_count > 0 ? '¥' . number_format($total_price / $price_count, 2) : '未设置';
                    ?>
                </div>
                <div class="stat-label">元/单位</div>
            </div>
        </div>

        <!-- 搜索和筛选区域 -->
        <div class="section">
            <h2>产品价格列表</h2>

            <form class="search-form" method="GET" action="">
                <div class="form-group">
                    <label for="product_type">产品类型:</label>
                    <select id="product_type" name="product_type">
                        <option value="finished" <?= $product_type == 'finished' ? 'selected' : '' ?>>成品</option>
                        <option value="semi-finished" <?= $product_type == 'semi-finished' ? 'selected' : '' ?>>半成品</option>
                        <option value="raw" <?= $product_type == 'raw' ? 'selected' : '' ?>>原料</option>
                    </select>
                </div>

                <div class="form-group">
                    <label for="keyword">关键词搜索:</label>
                    <input type="text" id="keyword" name="keyword" value="<?= htmlspecialchars($keyword) ?>" placeholder="产品名称/规格">
                </div>

                <div class="form-group" style="min-width: 200px;">
                    <label>
                        <input type="checkbox" name="promotion_only" value="1" <?= $show_promotion_only ? 'checked' : '' ?>>
                        只显示促销产品
                    </label>
                </div>

                <button type="submit" class="btn">搜索</button>
                <a href="price_management.php" class="btn btn-secondary">重置</a>
            </form>

            <!-- 产品价格列表 -->
            <?php if (empty($products)): ?>
                <div class="empty-state">
                    <p>没有找到符合条件的产品</p>
                </div>
            <?php else: ?>
                <form method="POST" action="">
                    <div class="table-container">
                        <table>
                            <thead>
                                <tr>
                                    <th>产品名称</th>
                                    <th>规格</th>
                                    <th>单位</th>
                                    <th>批发价 (¥)</th>
                                    <th>零售价 (¥)</th>
                                    <th>促销折扣</th>
                                    <th>促销期间</th>
                                    <th>终端售价</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($products as $index => $product): ?>
                                    <?php
                                    $has_promotion = !empty($product['promotion_discount']) &&
                                        $product['promotion_discount'] > 0 &&
                                        $product['promotion_end_date'] >= date('Y-m-d');
                                    $final_price = $product['retail_price'];
                                    if ($has_promotion) {
                                        $final_price = $product['retail_price'] * (1 - $product['promotion_discount']);
                                    }
                                    ?>
                                    <tr>
                                        <td>
                                            <?= htmlspecialchars($product['name']) ?>
                                            <input type="hidden" name="product_ids[]" value="<?= $product['id'] ?>">
                                        </td>
                                        <td><?= htmlspecialchars($product['specification'] ?: '-') ?></td>
                                        <td><?= htmlspecialchars($product['unit']) ?></td>
                                        <td>
                                            <input type="number" name="wholesale_price[]" step="0.01" min="0"
                                                value="<?= !empty($product['wholesale_price']) ? $product['wholesale_price'] : '' ?>"
                                                placeholder="设置批发价">
                                        </td>
                                        <td>
                                            <input type="number" name="retail_price[]" step="0.01" min="0"
                                                value="<?= !empty($product['retail_price']) ? $product['retail_price'] : '' ?>"
                                                placeholder="设置零售价">
                                        </td>
                                        <td>
                                            <?php if ($has_promotion): ?>
                                                <span class="promotion-tag"><?= number_format($product['promotion_discount'] * 100, 0) ?>% 折扣</span>
                                            <?php else: ?>
                                                无促销
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if ($has_promotion): ?>
                                                <?= date('Y-m-d', strtotime($product['promotion_start_date'])) ?> 至
                                                <?= date('Y-m-d', strtotime($product['promotion_end_date'])) ?>
                                            <?php else: ?>
                                                -
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if (!empty($product['retail_price'])): ?>
                                                <?php if ($has_promotion): ?>
                                                    <span class="price-display discounted">¥<?= number_format($final_price, 2) ?></span>
                                                    <span class="original-price">¥<?= number_format($product['retail_price'], 2) ?></span>
                                                <?php else: ?>
                                                    <span class="price-display">¥<?= number_format($product['retail_price'], 2) ?></span>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <span class="price-display">未设置</span>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if (!empty($product['retail_price'])): ?>
                                                <button type="button" class="btn btn-sm btn-success"
                                                    onclick="openPromotionModal(<?= $product['id'] ?>, '<?= htmlspecialchars($product['name']) ?>', <?= $product['retail_price'] ?>)">
                                                    设置促销
                                                </button>

                                                <?php if ($has_promotion): ?>
                                                    <a href="?cancel_promotion=<?= $product['id'] ?>&product_type=<?= $product_type ?>&keyword=<?= urlencode($keyword) ?>&promotion_only=<?= $show_promotion_only ? '1' : '0' ?>"
                                                        class="btn btn-sm btn-danger"
                                                        onclick="return confirm('确定要取消该产品的促销吗？')">
                                                        取消促销
                                                    </a>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <span class="text-muted">请先设置价格</span>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <div style="margin-top: 20px; text-align: center;">
                        <button type="submit" name="update_prices" class="btn btn-primary">批量更新价格</button>
                    </div>
                </form>
            <?php endif; ?>
        </div>

        <!-- 价格政策说明区域 -->
        <div class="section">
            <h2>价格政策说明</h2>

            <div style="display: flex; flex-wrap: wrap; gap: 20px;">
                <div style="flex: 1; min-width: 300px;">
                    <h3>批发价政策</h3>
                    <ul>
                        <li>批发价适用于批发商、分销商和大宗采购客户</li>
                        <li>批发价通常低于零售价25-30%</li>
                        <li>订购量超过指定数量可获得额外批发折扣</li>
                        <li>长期合作伙伴可申请特殊价格方案</li>
                    </ul>
                </div>

                <div style="flex: 1; min-width: 300px;">
                    <h3>零售价政策</h3>
                    <ul>
                        <li>零售价是面向终端消费者的建议零售价</li>
                        <li>零售价应考虑市场竞争、产品定位和利润要求</li>
                        <li>品牌产品的零售价应保持相对稳定</li>
                        <li>应定期评估和调整零售价格以反映市场变化</li>
                    </ul>
                </div>

                <div style="flex: 1; min-width: 300px;">
                    <h3>促销折扣政策</h3>
                    <ul>
                        <li>促销活动应有明确的开始和结束日期</li>
                        <li>促销折扣通常不超过原价的30%</li>
                        <li>季节性产品可在淡季提供更高折扣</li>
                        <li>促销活动应提前规划并与市场营销团队协调</li>
                    </ul>
                </div>
            </div>
        </div>
    </div>

    <!-- 促销设置模态框 -->
    <div id="promotion-modal" class="modal">
        <div class="modal-content">
            <div class="modal-header">
                <h3>设置促销折扣</h3>
                <span class="modal-close" onclick="closeModal()">&times;</span>
            </div>

            <form method="POST" action="">
                <input type="hidden" id="promotion_product_id" name="promotion_product_id" value="">

                <div class="form-group">
                    <label>产品名称:</label>
                    <input type="text" id="promotion_product_name" readonly>
                </div>

                <div class="form-group">
                    <label>当前零售价:</label>
                    <input type="text" id="promotion_retail_price" readonly>
                </div>

                <div class="form-group">
                    <label for="promotion_discount">促销折扣率 (%):</label>
                    <input type="number" id="promotion_discount" name="promotion_discount" min="1" max="99" value="10" required>
                </div>

                <div class="form-group">
                    <label for="promotion_start_date">促销开始日期:</label>
                    <input type="date" id="promotion_start_date" name="promotion_start_date" value="<?= date('Y-m-d') ?>" required>
                </div>

                <div class="form-group">
                    <label for="promotion_end_date">促销结束日期:</label>
                    <input type="date" id="promotion_end_date" name="promotion_end_date" value="<?= date('Y-m-d', strtotime('+30 days')) ?>" required>
                </div>

                <div class="form-group">
                    <label>促销后价格:</label>
                    <div id="final_price" class="price-display discounted" style="font-size: 18px; margin-top: 5px;"></div>
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" onclick="closeModal()">取消</button>
                    <button type="submit" name="set_promotion" class="btn btn-primary">保存促销设置</button>
                </div>
            </form>
        </div>
    </div>

    <script>
        // 打开促销模态框
        function openPromotionModal(productId, productName, retailPrice) {
            document.getElementById('promotion_product_id').value = productId;
            document.getElementById('promotion_product_name').value = productName;
            document.getElementById('promotion_retail_price').value = '¥' + retailPrice.toFixed(2);

            updateFinalPrice(retailPrice);

            document.getElementById('promotion-modal').style.display = 'block';

            // 监听折扣变化
            document.getElementById('promotion_discount').addEventListener('input', function() {
                updateFinalPrice(retailPrice);
            });
        }

        // 更新最终价格
        function updateFinalPrice(retailPrice) {
            const discountRate = document.getElementById('promotion_discount').value / 100;
            const finalPrice = retailPrice * (1 - discountRate);
            document.getElementById('final_price').textContent = '¥' + finalPrice.toFixed(2);
        }

        // 关闭模态框
        function closeModal() {
            document.getElementById('promotion-modal').style.display = 'none';
        }

        // 点击模态框外部关闭模态框
        window.onclick = function(event) {
            const modal = document.getElementById('promotion-modal');
            if (event.target == modal) {
                closeModal();
            }
        }
    </script>
</body>

</html>