<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取订单ID
$order_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$order_id) {
    $_SESSION['error'] = "未指定订单ID";
    header("Location: purchase_orders.php");
    exit;
}

try {
    // 获取采购订单信息
    $stmt = $pdo->prepare("
        SELECT 
            po.id, 
            po.order_number, 
            po.supplier_id,
            po.order_date, 
            po.expected_delivery_date, 
            po.status, 
            po.total_amount,
            s.name AS supplier_name
        FROM purchase_orders po
        JOIN suppliers s ON po.supplier_id = s.id
        WHERE po.id = ?
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch();

    if (!$order) {
        $_SESSION['error'] = "找不到该采购订单";
        header("Location: purchase_orders.php");
        exit;
    }

    // 检查订单状态是否为待审批
    if ($order['status'] !== 'pending') {
        $_SESSION['error'] = "只有待审批状态的订单可以编辑";
        header("Location: purchase_order_detail.php?id=" . $order_id);
        exit;
    }

    // 获取订单项
    $stmt = $pdo->prepare("
        SELECT 
            poi.id,
            poi.product_id,
            poi.quantity,
            poi.unit_price,
            p.name AS product_name,
            p.specification,
            p.unit
        FROM purchase_order_items poi
        JOIN products p ON poi.product_id = p.id
        WHERE poi.purchase_order_id = ?
    ");
    $stmt->execute([$order_id]);
    $orderItems = $stmt->fetchAll();

    // 获取所有供应商
    $stmt = $pdo->query("
        SELECT id, name, contact_person, phone
        FROM suppliers
        ORDER BY name
    ");
    $suppliers = $stmt->fetchAll();

    // 获取所有原料产品
    $stmt = $pdo->query("
        SELECT id, name, specification, unit
        FROM products
        WHERE type = 'raw'
        ORDER BY name
    ");
    $products = $stmt->fetchAll();

    // 如果是POST请求，处理编辑
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // CSRF验证
        if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
            $_SESSION['error'] = "安全验证失败，请重试";
            header("Location: purchase_order_edit.php?id=" . $order_id);
            exit;
        }

        // 验证必填字段
        $required_fields = ['supplier_id', 'order_date', 'expected_delivery_date'];
        foreach ($required_fields as $field) {
            if (!isset($_POST[$field]) || trim($_POST[$field]) === '') {
                $_SESSION['error'] = "{$field}是必填项";
                header("Location: purchase_order_edit.php?id=" . $order_id);
                exit;
            }
        }

        $pdo->beginTransaction();

        // 更新采购订单信息
        $stmt = $pdo->prepare("
            UPDATE purchase_orders 
            SET 
                supplier_id = ?,
                order_date = ?,
                expected_delivery_date = ?
            WHERE id = ?
        ");
        $stmt->execute([
            $_POST['supplier_id'],
            $_POST['order_date'],
            $_POST['expected_delivery_date'],
            $order_id
        ]);

        // 处理订单项 - 删除现有项并添加新项
        $stmt = $pdo->prepare("DELETE FROM purchase_order_items WHERE purchase_order_id = ?");
        $stmt->execute([$order_id]);

        // 添加新订单项
        $total_amount = 0;

        $product_ids = $_POST['product_id'] ?? [];
        $quantities = $_POST['quantity'] ?? [];
        $unit_prices = $_POST['unit_price'] ?? [];

        for ($i = 0; $i < count($product_ids); $i++) {
            if (empty($product_ids[$i]) || empty($quantities[$i]) || empty($unit_prices[$i])) {
                continue; // 跳过空项
            }

            $product_id = (int)$product_ids[$i];
            $quantity = (float)$quantities[$i];
            $unit_price = (float)$unit_prices[$i];
            $item_total = $quantity * $unit_price;
            $total_amount += $item_total;

            $stmt = $pdo->prepare("
                INSERT INTO purchase_order_items (
                    purchase_order_id,
                    product_id,
                    quantity,
                    unit_price,
                    received_quantity
                ) VALUES (?, ?, ?, ?, 0)
            ");
            $stmt->execute([
                $order_id,
                $product_id,
                $quantity,
                $unit_price
            ]);
        }

        // 更新订单总金额
        $stmt = $pdo->prepare("
            UPDATE purchase_orders 
            SET total_amount = ? 
            WHERE id = ?
        ");
        $stmt->execute([$total_amount, $order_id]);

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '编辑采购订单',
            'purchase_order',
            $order_id,
            json_encode([
                'order_number' => $order['order_number'],
                'total_amount' => $total_amount
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "采购订单已成功更新";
        header("Location: purchase_order_detail.php?id=" . $order_id);
        exit;
    }
} catch (PDOException $e) {
    if (isset($pdo) && $pdo->inTransaction()) {
        $pdo->rollBack();
    }
    $_SESSION['error'] = "数据库错误：" . $e->getMessage();
    header("Location: purchase_orders.php");
    exit;
}
?>

<!DOCTYPE html>
<html>

<head>
    <title>编辑采购订单</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .order-items {
            margin-top: 20px;
        }

        .item-row {
            display: grid;
            grid-template-columns: 5fr 1fr 1fr 1fr 0.5fr;
            gap: 10px;
            margin-bottom: 10px;
            align-items: center;
        }

        .item-header {
            font-weight: bold;
            border-bottom: 1px solid #ddd;
            padding-bottom: 10px;
            margin-bottom: 15px;
        }

        .remove-item {
            color: #dc3545;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
        }

        #add-item-btn {
            margin-top: 15px;
            background-color: #28a745;
        }

        .form-info {
            background-color: #f8f9fa;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }

        .form-info-title {
            font-weight: bold;
            margin-bottom: 10px;
            color: #2c3e50;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>编辑采购订单</h2>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="form-info">
            <div class="form-info-title">订单信息</div>
            <div><strong>订单编号:</strong> <?= htmlspecialchars($order['order_number']) ?></div>
            <div><strong>当前状态:</strong> 待审批</div>
        </div>

        <div class="form-container">
            <form method="POST">
                <?= csrf_field() ?>

                <div class="form-group">
                    <label>供应商</label>
                    <select name="supplier_id" required>
                        <option value="">请选择供应商</option>
                        <?php foreach ($suppliers as $supplier): ?>
                            <option value="<?= $supplier['id'] ?>" <?= ($supplier['id'] == $order['supplier_id']) ? 'selected' : '' ?>>
                                <?= htmlspecialchars($supplier['name']) ?>
                                <?= $supplier['contact_person'] ? ' (' . htmlspecialchars($supplier['contact_person']) . ')' : '' ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>订单日期</label>
                    <input type="date" name="order_date" value="<?= date('Y-m-d', strtotime($order['order_date'])) ?>" required>
                </div>

                <div class="form-group">
                    <label>预计交货日期</label>
                    <input type="date" name="expected_delivery_date" value="<?= date('Y-m-d', strtotime($order['expected_delivery_date'])) ?>" required>
                </div>

                <h3>订单项目</h3>

                <div class="order-items">
                    <div class="item-row item-header">
                        <div>产品</div>
                        <div>数量</div>
                        <div>单价 (¥)</div>
                        <div>金额 (¥)</div>
                        <div></div>
                    </div>

                    <div id="items-container">
                        <?php foreach ($orderItems as $index => $item): ?>
                            <div class="item-row">
                                <div>
                                    <select name="product_id[]" required class="product-select" onchange="updateProductInfo(this)">
                                        <option value="">选择产品</option>
                                        <?php foreach ($products as $product): ?>
                                            <option value="<?= $product['id'] ?>"
                                                data-unit="<?= htmlspecialchars($product['unit']) ?>"
                                                data-spec="<?= htmlspecialchars($product['specification'] ?? '') ?>"
                                                <?= ($product['id'] == $item['product_id']) ? 'selected' : '' ?>>
                                                <?= htmlspecialchars($product['name']) ?>
                                                <?= $product['specification'] ? '(' . htmlspecialchars($product['specification']) . ')' : '' ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                    <span class="product-info">
                                        <?php if ($item['specification']): ?>
                                            规格: <?= htmlspecialchars($item['specification']) ?>,
                                        <?php endif; ?>
                                        单位: <?= htmlspecialchars($item['unit']) ?>
                                    </span>
                                </div>
                                <div>
                                    <input type="number" name="quantity[]" min="0.01" step="0.01" value="<?= $item['quantity'] ?>" required class="quantity-input" onchange="calculateItemTotal(this)">
                                </div>
                                <div>
                                    <input type="number" name="unit_price[]" min="0.01" step="0.01" value="<?= $item['unit_price'] ?>" required class="price-input" onchange="calculateItemTotal(this)">
                                </div>
                                <div>
                                    <span class="item-total"><?= number_format($item['quantity'] * $item['unit_price'], 2) ?></span>
                                </div>
                                <div>
                                    <span class="remove-item" onclick="removeItem(this)">×</span>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <button type="button" id="add-item-btn" class="btn" onclick="addItem()">添加产品</button>
                </div>

                <div class="form-group" style="margin-top: 30px; text-align: right;">
                    <span style="margin-right: 20px; font-weight: bold;">订单总金额: ¥<span id="order-total">0.00</span></span>
                </div>

                <div class="form-group">
                    <button type="submit" class="btn">保存修改</button>
                    <a href="purchase_order_detail.php?id=<?= $order_id ?>" class="btn" style="background-color: #6c757d; margin-left: 10px;">取消</a>
                </div>
            </form>
        </div>
    </div>

    <script>
        // 计算初始订单总额
        window.onload = function() {
            calculateOrderTotal();
        };

        // 添加新项目
        function addItem() {
            const container = document.getElementById('items-container');
            const newRow = document.createElement('div');
            newRow.className = 'item-row';

            // 产品选择列表的HTML，复制第一个产品选择框的选项
            const productSelectHTML = document.querySelector('.product-select').outerHTML;

            newRow.innerHTML = `
                <div>
                    ${productSelectHTML}
                    <span class="product-info"></span>
                </div>
                <div>
                    <input type="number" name="quantity[]" min="0.01" step="0.01" value="1" required class="quantity-input" onchange="calculateItemTotal(this)">
                </div>
                <div>
                    <input type="number" name="unit_price[]" min="0.01" step="0.01" value="0" required class="price-input" onchange="calculateItemTotal(this)">
                </div>
                <div>
                    <span class="item-total">0.00</span>
                </div>
                <div>
                    <span class="remove-item" onclick="removeItem(this)">×</span>
                </div>
            `;

            container.appendChild(newRow);

            // 重置新添加行的产品选择
            const newSelect = newRow.querySelector('.product-select');
            newSelect.selectedIndex = 0;
            newSelect.onchange = function() {
                updateProductInfo(this);
            };
        }

        // 移除项目
        function removeItem(element) {
            const row = element.closest('.item-row');
            row.remove();
            calculateOrderTotal();
        }

        // 更新产品信息
        function updateProductInfo(selectElement) {
            const row = selectElement.closest('.item-row');
            const option = selectElement.options[selectElement.selectedIndex];
            const infoSpan = row.querySelector('.product-info');

            if (option.value) {
                const unit = option.getAttribute('data-unit');
                const spec = option.getAttribute('data-spec');

                let infoText = '';
                if (spec) {
                    infoText += `规格: ${spec}, `;
                }
                infoText += `单位: ${unit}`;

                infoSpan.textContent = infoText;
            } else {
                infoSpan.textContent = '';
            }

            calculateItemTotal(selectElement);
        }

        // 计算项目总额
        function calculateItemTotal(element) {
            const row = element.closest('.item-row');
            const quantity = parseFloat(row.querySelector('.quantity-input').value) || 0;
            const price = parseFloat(row.querySelector('.price-input').value) || 0;
            const total = quantity * price;

            row.querySelector('.item-total').textContent = total.toFixed(2);
            calculateOrderTotal();
        }

        // 计算订单总额
        function calculateOrderTotal() {
            const totals = document.querySelectorAll('.item-total');
            let orderTotal = 0;

            totals.forEach(function(element) {
                orderTotal += parseFloat(element.textContent) || 0;
            });

            document.getElementById('order-total').textContent = orderTotal.toFixed(2);
        }
    </script>
</body>

</html>