<?php
session_start();
require_once '../config.php';

// 检查权限
if (!is_admin()) {
    header("HTTP/1.1 403 Forbidden");
    exit("<div class='alert alert-danger'>权限不足，无法访问此页面</div>");
}

// 备份目录配置
$backup_dir = __DIR__ . '/../backups/';
if (!file_exists($backup_dir)) mkdir($backup_dir, 0755, true);

// 处理操作请求
if (isset($_GET['action'])) {
    switch ($_GET['action']) {
        case 'backup':
            // 手动备份操作
            $filename = 'fruitease_backup_' . date('YmdHis') . '.sql';
            $full_path = $backup_dir . $filename;

            try {
                // 验证用户会话
                if (!isset($_SESSION['user_id'])) {
                    throw new Exception("用户未登录");
                }

                // 执行PHP备份（不依赖mysqldump）
                $success = backupDatabaseTables($pdo, $full_path);

                if (!$success) {
                    throw new Exception("备份失败");
                }

                // 验证文件已创建
                if (!file_exists($full_path) || filesize($full_path) == 0) {
                    throw new Exception("备份文件创建失败");
                }

                // 记录到操作日志
                $stmt = $pdo->prepare("
                    INSERT INTO activity_log 
                    (user_id, username, action, target_type, target_id, details, ip_address) 
                    VALUES (?, ?, ?, ?, ?, ?, ?)
                ");

                $stmt->execute([
                    $_SESSION['user_id'],
                    $_SESSION['username'],
                    '手动备份数据库',
                    'backup',
                    null,
                    json_encode([
                        'filename' => $filename,
                        'filesize' => filesize($full_path),
                        'path' => $full_path
                    ]),
                    $_SERVER['REMOTE_ADDR']
                ]);

                $_SESSION['success'] = "数据库备份成功！文件: $filename";
            } catch (Exception $e) {
                $_SESSION['error'] = "备份失败: " . $e->getMessage();
            }
            break;

        case 'delete':
            // 删除备份文件
            $file = isset($_GET['file']) ? basename($_GET['file']) : '';
            $file_path = $backup_dir . $file;

            try {
                if (empty($file) || !file_exists($file_path)) {
                    throw new Exception("文件不存在");
                }

                if (!unlink($file_path)) {
                    throw new Exception("文件删除失败");
                }

                // 记录到操作日志
                $stmt = $pdo->prepare("
                    INSERT INTO activity_log 
                    (user_id, username, action, target_type, target_id, details, ip_address) 
                    VALUES (?, ?, ?, ?, ?, ?, ?)
                ");

                $stmt->execute([
                    $_SESSION['user_id'],
                    $_SESSION['username'],
                    '删除备份文件',
                    'backup',
                    null,
                    json_encode(['deleted_file' => $file]),
                    $_SERVER['REMOTE_ADDR']
                ]);

                $_SESSION['success'] = "备份文件 '$file' 已删除";
            } catch (Exception $e) {
                $_SESSION['error'] = $e->getMessage();
            }
            break;

        case 'restore':
            // 恢复备份
            $file = isset($_GET['file']) ? basename($_GET['file']) : '';
            $file_path = $backup_dir . $file;

            try {
                if (empty($file) || !file_exists($file_path)) {
                    throw new Exception("备份文件不存在");
                }

                if (!is_readable($file_path)) {
                    throw new Exception("备份文件不可读取");
                }

                // 执行PHP恢复（不依赖mysql命令）
                $success = restoreDatabase($pdo, $file_path);

                if (!$success) {
                    throw new Exception("恢复数据失败");
                }

                // 记录到操作日志
                $stmt = $pdo->prepare("
                    INSERT INTO activity_log 
                    (user_id, username, action, target_type, target_id, details, ip_address) 
                    VALUES (?, ?, ?, ?, ?, ?, ?)
                ");

                $stmt->execute([
                    $_SESSION['user_id'],
                    $_SESSION['username'],
                    '恢复数据库备份',
                    'backup',
                    null,
                    json_encode([
                        'restored_file' => $file,
                        'filesize' => filesize($file_path)
                    ]),
                    $_SERVER['REMOTE_ADDR']
                ]);

                $_SESSION['success'] = "数据库已从备份 '$file' 恢复";
            } catch (Exception $e) {
                $_SESSION['error'] = "恢复失败: " . $e->getMessage();
            }
            break;
    }

    header("Location: data_backup.php");
    exit;
}

// 获取备份文件列表
$backup_files = [];
if (is_dir($backup_dir)) {
    $files = scandir($backup_dir);
    foreach ($files as $file) {
        if ($file != '.' && $file != '..' && pathinfo($file, PATHINFO_EXTENSION) == 'sql') {
            $file_path = $backup_dir . $file;
            $backup_files[] = [
                'filename' => $file,
                'filesize' => filesize($file_path),
                'created' => filemtime($file_path)
            ];
        }
    }

    // 按创建时间倒序排序
    usort($backup_files, function ($a, $b) {
        return $b['created'] - $a['created'];
    });
}

// 获取最近7天的备份日志
$recent_logs = $pdo->query("
    SELECT 
        user_id,
        username,
        action,
        details,
        timestamp
    FROM activity_log
    WHERE action IN ('手动备份数据库', '恢复数据库备份', '删除备份文件')
    ORDER BY timestamp DESC
    LIMIT 20
")->fetchAll();

/**
 * 备份数据库表到SQL文件
 * @param PDO $pdo 数据库连接
 * @param string $backup_file 备份文件路径
 * @return bool 是否成功
 */
function backupDatabaseTables($pdo, $backup_file)
{
    try {
        $output = "-- 果易管系统数据库备份\n";
        $output .= "-- 创建日期: " . date("Y-m-d H:i:s") . "\n";
        $output .= "-- 主机: " . DB_HOST . "\n";
        $output .= "-- 数据库: " . DB_NAME . "\n\n";

        // 获取所有表
        $tables = [];
        $result = $pdo->query("SHOW TABLES");
        while ($row = $result->fetch(PDO::FETCH_NUM)) {
            $tables[] = $row[0];
        }

        // 备份每张表结构和数据
        foreach ($tables as $table) {
            // 表结构
            $output .= "-- 表结构 `$table`\n";
            $output .= "DROP TABLE IF EXISTS `$table`;\n";

            $row = $pdo->query("SHOW CREATE TABLE `$table`")->fetch(PDO::FETCH_NUM);
            $output .= $row[1] . ";\n\n";

            // 表数据
            $output .= "-- 表数据 `$table`\n";
            $rows = $pdo->query("SELECT * FROM `$table`")->fetchAll(PDO::FETCH_ASSOC);

            if (count($rows) > 0) {
                $columns = array_keys($rows[0]);
                $output .= "INSERT INTO `$table` (`" . implode("`, `", $columns) . "`) VALUES\n";

                $values = [];
                foreach ($rows as $row) {
                    $row_values = [];
                    foreach ($row as $value) {
                        if ($value === null) {
                            $row_values[] = "NULL";
                        } elseif (is_numeric($value)) {
                            $row_values[] = $value;
                        } else {
                            $row_values[] = "'" . addslashes($value) . "'";
                        }
                    }
                    $values[] = "(" . implode(", ", $row_values) . ")";
                }

                $output .= implode(",\n", $values) . ";\n\n";
            }
        }

        // 写入文件
        return file_put_contents($backup_file, $output) !== false;
    } catch (Exception $e) {
        error_log("备份失败: " . $e->getMessage());
        return false;
    }
}

/**
 * 从SQL文件恢复数据库
 * @param PDO $pdo 数据库连接
 * @param string $backup_file 备份文件路径
 * @return bool 是否成功
 */
function restoreDatabase($pdo, $backup_file)
{
    try {
        $sql = file_get_contents($backup_file);
        if ($sql === false) {
            throw new Exception("无法读取备份文件");
        }

        // 启用多语句执行模式
        $pdo->setAttribute(PDO::ATTR_EMULATE_PREPARES, 1);

        // 分割SQL语句 - 改进分割方式，避免拆分包含分号的内容
        $queries = [];
        $current = '';
        $delimiter = ';';
        $lines = explode("\n", $sql);

        foreach ($lines as $line) {
            // 跳过注释行
            if (substr(trim($line), 0, 2) == '--' || substr(trim($line), 0, 1) == '#') {
                continue;
            }

            $current .= $line . "\n";

            // 检查行尾是否为分隔符
            if (rtrim($line) == $delimiter) {
                $queries[] = $current;
                $current = '';
            }
        }

        // 添加最后一个查询（如果有）
        if (!empty(trim($current))) {
            $queries[] = $current;
        }

        // 开始事务
        $pdo->beginTransaction();

        // 暂时禁用外键约束
        $pdo->exec('SET FOREIGN_KEY_CHECKS = 0');

        foreach ($queries as $query) {
            $query = trim($query);
            if (!empty($query)) {
                try {
                    $pdo->exec($query);
                } catch (PDOException $e) {
                    // 记录详细错误但继续执行
                    error_log("恢复SQL执行错误: " . $e->getMessage() . " 在查询: " . substr($query, 0, 100) . "...");
                    continue;
                }
            }
        }

        // 重新启用外键约束
        $pdo->exec('SET FOREIGN_KEY_CHECKS = 1');

        $pdo->commit();
        return true;
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        error_log("恢复失败: " . $e->getMessage());
        return false;
    }
}
?>

<!DOCTYPE html>
<html>

<head>
    <title>数据备份与恢复 - 果易管系统</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .backup-actions {
            display: flex;
            gap: 5px;
        }

        .backup-warning {
            background-color: #fff3cd;
            border-left: 4px solid #ffc107;
            padding: 10px 15px;
            margin-bottom: 20px;
        }

        .restore-btn {
            background: #28a745;
            padding: 4px 8px;
            border-radius: 4px;
            color: white;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>数据备份与恢复</h2>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="backup-warning">
            <h4>重要提示</h4>
            <p>恢复操作将覆盖当前数据库中的所有数据，请谨慎操作！建议在恢复前先进行一次备份。</p>
        </div>

        <div class="form-container">
            <div class="toolbar">
                <a href="data_backup.php?action=backup"
                    class="btn"
                    onclick="return confirm('确认执行数据库备份？')">
                    立即备份
                </a>
            </div>

            <h3>备份文件列表</h3>
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>备份文件名</th>
                            <th>文件大小</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($backup_files)): ?>
                            <tr>
                                <td colspan="4" class="empty-state">暂无备份文件</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($backup_files as $backup): ?>
                                <tr>
                                    <td><?= htmlspecialchars($backup['filename']) ?></td>
                                    <td><?= round($backup['filesize'] / 1024, 2) ?> KB</td>
                                    <td><?= date('Y-m-d H:i:s', $backup['created']) ?></td>
                                    <td class="backup-actions">
                                        <a href="data_backup.php?action=restore&file=<?= urlencode($backup['filename']) ?>"
                                            class="restore-btn"
                                            onclick="return confirm('警告：恢复操作将覆盖当前所有数据！\n确定要从此备份恢复数据库吗？')">
                                            恢复
                                        </a>
                                        <a href="data_backup.php?action=delete&file=<?= urlencode($backup['filename']) ?>"
                                            class="btn-delete"
                                            onclick="return confirm('确认删除此备份文件？')">
                                            删除
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <div class="form-container">
            <h3>备份操作日志</h3>
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>时间</th>
                            <th>用户</th>
                            <th>操作</th>
                            <th>详情</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($recent_logs)): ?>
                            <tr>
                                <td colspan="4" class="empty-state">暂无备份操作日志</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($recent_logs as $log): ?>
                                <tr>
                                    <td><?= date('Y-m-d H:i:s', strtotime($log['timestamp'])) ?></td>
                                    <td><?= htmlspecialchars($log['username']) ?></td>
                                    <td><?= htmlspecialchars($log['action']) ?></td>
                                    <td>
                                        <?php
                                        $details = json_decode($log['details'], true);
                                        if ($details) {
                                            foreach ($details as $key => $value) {
                                                if ($key == 'path' || $key == 'details') continue;
                                                echo htmlspecialchars($key) . ': ' . htmlspecialchars($value) . '<br>';
                                            }
                                        }
                                        ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>