<?php
session_start();
require_once '../config.php';

// 检查权限
if (!is_admin()) {
    header("HTTP/1.1 403 Forbidden");
    exit("<div class='alert alert-danger'>权限不足，无法访问此页面</div>");
}

// 获取用户ID
$user_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if ($user_id <= 0) {
    header("Location: user_management.php");
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 验证CSRF Token
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $_SESSION['error'] = "安全验证失败，请重试";
        header("Location: user_edit.php?id=$user_id");
        exit;
    }

    // 获取表单数据
    $full_name = trim($_POST['full_name'] ?? '');
    $email = trim($_POST['email'] ?? '');
    $phone = trim($_POST['phone'] ?? '');
    $role_id = (int)($_POST['role_id'] ?? 0);
    $password = $_POST['password'] ?? '';
    $is_active = isset($_POST['is_active']) ? 1 : 0;

    try {
        $pdo->beginTransaction();

        // 获取当前用户信息
        $stmt = $pdo->prepare("
            SELECT u.*, r.name AS role_name 
            FROM users u 
            JOIN roles r ON u.role_id = r.id
            WHERE u.id = ?
        ");
        $stmt->execute([$user_id]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$user) {
            throw new Exception("用户不存在");
        }

        // 如果是最后一个管理员，不能禁用或改变角色
        if ($user['role_name'] == '管理员') {
            $stmt = $pdo->prepare("
                SELECT COUNT(*) FROM users u 
                JOIN roles r ON u.role_id = r.id
                WHERE r.name = '管理员' AND u.id != ? AND u.is_active = 1
            ");
            $stmt->execute([$user_id]);
            $adminCount = $stmt->fetchColumn();

            if ($adminCount < 1) {
                if (!$is_active) {
                    throw new Exception("不能禁用最后一个管理员账户");
                }

                // 获取选择的新角色名称
                $stmt = $pdo->prepare("SELECT name FROM roles WHERE id = ?");
                $stmt->execute([$role_id]);
                $newRoleName = $stmt->fetchColumn();

                if ($newRoleName != '管理员') {
                    throw new Exception("不能更改最后一个管理员的角色");
                }
            }
        }

        // 检查邮箱是否已存在
        if (!empty($email) && $email != $user['email']) {
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM users WHERE email = ? AND id != ? AND email IS NOT NULL");
            $stmt->execute([$email, $user_id]);
            if ($stmt->fetchColumn() > 0) {
                throw new Exception("邮箱 '$email' 已被使用");
            }
        }

        // 检查手机号是否已存在
        if (!empty($phone) && $phone != $user['phone']) {
            $stmt = $pdo->prepare("SELECT COUNT(*) FROM users WHERE phone = ? AND id != ? AND phone IS NOT NULL");
            $stmt->execute([$phone, $user_id]);
            if ($stmt->fetchColumn() > 0) {
                throw new Exception("手机号 '$phone' 已被使用");
            }
        }

        // 构建更新查询
        $updateFields = [
            "full_name = ?",
            "email = ?",
            "phone = ?",
            "role_id = ?",
            "is_active = ?",
            "updated_at = CURRENT_TIMESTAMP"
        ];
        $params = [
            $full_name ?: null,
            $email ?: null,
            $phone ?: null,
            $role_id,
            $is_active
        ];

        // 如果提供了新密码，则更新密码
        if (!empty($password)) {
            $updateFields[] = "password_hash = ?";
            $params[] = password_hash($password, PASSWORD_DEFAULT);
        }

        // 添加用户ID作为条件参数
        $params[] = $user_id;

        // 执行更新
        $sql = "UPDATE users SET " . implode(", ", $updateFields) . " WHERE id = ?";
        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);

        // 记录操作日志
        $changes = [
            'user_id' => $user_id,
            'full_name_changed' => $full_name != $user['full_name'],
            'email_changed' => $email != $user['email'],
            'phone_changed' => $phone != $user['phone'],
            'role_changed' => $role_id != $user['role_id'],
            'password_changed' => !empty($password),
            'status_changed' => $is_active != $user['is_active']
        ];

        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");

        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '更新用户信息',
            'user',
            $user_id,
            json_encode($changes),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "用户信息更新成功";
        header("Location: user_management.php");
        exit;
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = $e->getMessage();
        header("Location: user_edit.php?id=$user_id");
        exit;
    }
}

// 获取用户信息
try {
    $stmt = $pdo->prepare("SELECT * FROM users WHERE id = ?");
    $stmt->execute([$user_id]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$user) {
        $_SESSION['error'] = "用户不存在";
        header("Location: user_management.php");
        exit;
    }

    // 获取所有角色
    $roles = $pdo->query("SELECT id, name, description FROM roles ORDER BY id")->fetchAll();
} catch (PDOException $e) {
    $_SESSION['error'] = "数据库错误: " . $e->getMessage();
    header("Location: user_management.php");
    exit;
}
?>
<!DOCTYPE html>
<html>

<head>
    <title>编辑用户 - 果易管系统</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>编辑用户</h2>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="form-container">
            <form method="POST">
                <?= csrf_field() ?>
                <div class="form-group">
                    <label>用户名</label>
                    <input type="text" value="<?= htmlspecialchars($user['username']) ?>" disabled>
                    <small>用户名不可修改</small>
                </div>

                <div class="form-group">
                    <label>姓名</label>
                    <input type="text" name="full_name" value="<?= htmlspecialchars($user['full_name'] ?? '') ?>">
                </div>

                <div class="form-group">
                    <label>邮箱</label>
                    <input type="email" name="email" value="<?= htmlspecialchars($user['email'] ?? '') ?>">
                </div>

                <div class="form-group">
                    <label>手机号</label>
                    <input type="text" name="phone" pattern="[0-9]{11}" value="<?= htmlspecialchars($user['phone'] ?? '') ?>">
                </div>

                <div class="form-group">
                    <label>角色</label>
                    <select name="role_id" required>
                        <?php foreach ($roles as $role): ?>
                            <option value="<?= $role['id'] ?>" <?= $user['role_id'] == $role['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($role['name']) ?> - <?= htmlspecialchars($role['description']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>新密码</label>
                    <input type="password" name="password">
                    <small>留空表示不修改密码</small>
                </div>

                <div class="form-group">
                    <label class="checkbox-label">
                        <input type="checkbox" name="is_active" <?= $user['is_active'] ? 'checked' : '' ?>>
                        启用账户
                    </label>
                </div>

                <div class="form-group">
                    <button type="submit" class="btn">保存更改</button>
                    <a href="user_management.php" class="btn-secondary">返回列表</a>
                </div>
            </form>
        </div>
    </div>
</body>

</html>