<?php
session_start();
require_once '../config.php';

// 检查权限
if (!is_admin()) {
    header("HTTP/1.1 403 Forbidden");
    exit("<div class='alert alert-danger'>权限不足，无法访问此页面</div>");
}

// 删除用户
if (isset($_GET['delete']) && is_admin()) {
    $user_id = (int)$_GET['delete'];

    // 检查是否为前四个用户（不允许删除）
    if ($user_id <= 4) {
        $_SESSION['error'] = "系统默认用户不能被禁用";
        header("Location: user_management.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 检查是否为最后一个管理员
        $stmt = $pdo->prepare("
            SELECT COUNT(*) FROM users u 
            JOIN roles r ON u.role_id = r.id 
            WHERE r.name = '管理员' AND u.id != ? AND u.is_active = 1
        ");
        $stmt->execute([$user_id]);
        $adminCount = $stmt->fetchColumn();

        // 获取要删除的用户角色
        $stmt = $pdo->prepare("
            SELECT r.name FROM users u 
            JOIN roles r ON u.role_id = r.id 
            WHERE u.id = ?
        ");
        $stmt->execute([$user_id]);
        $roleName = $stmt->fetchColumn();

        if ($roleName == '管理员' && $adminCount < 1) {
            throw new Exception("无法删除最后一个管理员账户");
        }

        // 删除用户
        $stmt = $pdo->prepare("UPDATE users SET is_active = 0 WHERE id = ?");
        $stmt->execute([$user_id]);

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '禁用用户',
            'user',
            $user_id,
            json_encode(['disabled_user_id' => $user_id]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "用户已禁用";
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = $e->getMessage();
    }
    header("Location: user_management.php");
    exit;
}

// 添加用户完全删除功能
if (isset($_GET['permanent_delete']) && is_admin()) {
    $user_id = (int)$_GET['permanent_delete'];

    // 检查是否为前四个用户（不允许删除）
    if ($user_id <= 4) {
        $_SESSION['error'] = "系统默认用户不能被删除";
        header("Location: user_management.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 检查是否为最后一个管理员
        $stmt = $pdo->prepare("
            SELECT COUNT(*) FROM users u 
            JOIN roles r ON u.role_id = r.id 
            WHERE r.name = '管理员' AND u.id != ? AND u.is_active = 1
        ");
        $stmt->execute([$user_id]);
        $adminCount = $stmt->fetchColumn();

        // 获取要删除的用户角色
        $stmt = $pdo->prepare("
            SELECT r.name FROM users u 
            JOIN roles r ON u.role_id = r.id 
            WHERE u.id = ?
        ");
        $stmt->execute([$user_id]);
        $roleName = $stmt->fetchColumn();

        if ($roleName == '管理员' && $adminCount < 1) {
            throw new Exception("无法删除最后一个管理员账户");
        }

        // 完全删除用户
        $stmt = $pdo->prepare("DELETE FROM users WHERE id = ?");
        $stmt->execute([$user_id]);

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '删除用户',
            'user',
            $user_id,
            json_encode(['deleted_user_id' => $user_id]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "用户已永久删除";
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = $e->getMessage();
    }
    header("Location: user_management.php");
    exit;
}

// 获取所有角色
$roles = $pdo->query("SELECT id, name, description FROM roles ORDER BY id")->fetchAll();

// 获取所有用户
$users = $pdo->query("
    SELECT 
        u.id,
        u.username,
        u.full_name,
        u.email,
        r.name AS role_name,
        u.last_login_at,
        u.is_active
    FROM users u
    JOIN roles r ON u.role_id = r.id
    ORDER BY r.name, u.username
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>用户角色管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 确保按钮样式正确显示 - 增加优先级 */
        .btn-edit,
        .btn-delete,
        .btn-permanent-delete {
            display: inline-block !important;
            padding: 4px 8px !important;
            border-radius: 4px !important;
            color: white !important;
            text-decoration: none !important;
            margin: 2px !important;
            font-weight: normal !important;
        }

        .btn-edit {
            background: #17a2b8 !important;
        }

        .btn-delete {
            background: #dc3545 !important;
        }

        .btn-permanent-delete {
            background: #8B0000 !important;
            /* 深红色 */
        }

        .text-muted {
            color: #6c757d !important;
        }

        .warning-row {
            background-color: #fff3cd !important;
        }

        /* 确保按钮行宽度足够 */
        td:last-child {
            min-width: 120px !important;
            white-space: nowrap !important;
        }

        /* 确保表格样式正确 */
        .table-container table {
            width: 100% !important;
            border-collapse: collapse !important;
            margin-bottom: 20px !important;
        }

        .table-container th,
        .table-container td {
            padding: 10px !important;
            border: 1px solid #ddd !important;
            text-align: left !important;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>用户角色管理</h2>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 用户创建表单 -->
        <div class="form-container">
            <h3>创建新用户</h3>
            <form method="POST" action="user_create.php">
                <?= csrf_field() ?>
                <div class="form-group">
                    <label>用户名</label>
                    <input type="text" name="username" required
                        pattern="[A-Za-z0-9_]{3,20}"
                        title="3-20位字母、数字或下划线">
                </div>

                <div class="form-group">
                    <label>姓名</label>
                    <input type="text" name="full_name">
                </div>

                <div class="form-group">
                    <label>邮箱</label>
                    <input type="email" name="email">
                </div>

                <div class="form-group">
                    <label>手机号</label>
                    <input type="text" name="phone" pattern="[0-9]{11}">
                </div>

                <div class="form-group">
                    <label>密码</label>
                    <input type="password" name="password" required minlength="6">
                </div>

                <div class="form-group">
                    <label>角色</label>
                    <select name="role_id" required>
                        <?php foreach ($roles as $role): ?>
                            <option value="<?= $role['id'] ?>"><?= $role['name'] ?> - <?= $role['description'] ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit" class="btn">创建用户</button>
            </form>
        </div>

        <!-- 用户列表 -->
        <div class="table-container">
            <h3>现有用户</h3>
            <table>
                <thead>
                    <tr>
                        <th>用户名</th>
                        <th>姓名</th>
                        <th>邮箱</th>
                        <th>角色</th>
                        <th>最后登录</th>
                        <th>状态</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($users as $user): ?>
                        <tr class="<?= $user['is_active'] ? '' : 'warning-row' ?>">
                            <td><?= htmlspecialchars($user['username']) ?></td>
                            <td><?= htmlspecialchars($user['full_name'] ?? '未设置') ?></td>
                            <td><?= htmlspecialchars($user['email'] ?? '未设置') ?></td>
                            <td><?= htmlspecialchars($user['role_name']) ?></td>
                            <td><?= $user['last_login_at'] ? date('Y-m-d H:i', strtotime($user['last_login_at'])) : '从未登录' ?></td>
                            <td><?= $user['is_active'] ? '启用' : '已禁用' ?></td>
                            <td>
                                <?php if ($user['id'] > 4): ?>
                                    <!-- 只有ID>4的用户才显示编辑和禁用和删除按钮 -->
                                    <a href="user_edit.php?id=<?= $user['id'] ?>" class="btn-edit">编辑</a>
                                    <?php if ($user['is_active']): ?>
                                        <a href="user_management.php?delete=<?= $user['id'] ?>"
                                            onclick="return confirm('确认禁用该用户？')"
                                            class="btn-delete">禁用</a>
                                    <?php else: ?>
                                        <a href="user_activate.php?id=<?= $user['id'] ?>"
                                            onclick="return confirm('确认重新启用该用户？')"
                                            class="btn-edit">启用</a>
                                    <?php endif; ?>
                                    <a href="user_management.php?permanent_delete=<?= $user['id'] ?>"
                                        onclick="return confirm('警告：此操作将永久删除该用户，无法恢复！确认要删除吗？')"
                                        class="btn-permanent-delete">删除</a>
                                <?php else: ?>
                                    <span class="text-muted">系统用户</span>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>